const { google } = require('googleapis');
const key = require('./auth.json'); // Downloaded JSON file

export const getMostVisited = () => {
  const viewId = '188655610'; // Google Analytics view ID
  const analytics = google.analyticsreporting('v4'); // Used for pulling report
  const jwtClient = new google.auth.JWT(
    key.client_email, // For authenticating and permissions
    null,
    key.private_key,
    ['https://www.googleapis.com/auth/analytics.readonly'],
    null,
  );

  jwtClient.authorize((err: any, tokens: any) => {
    if (err) {
      console.log(err);
      return;
    }
  });

  const metrics = {
    expression: 'ga:uniquePageviews',
  };

  const dimensions = [
    { name: 'ga:pagePath' },
    // { name: 'ga:pageTitle' }
  ];

  const orderBys = [
    {
      fieldName: 'ga:uniquePageviews',
      sortOrder: 'DESCENDING',
    },
  ];

  const dateRanges = [
    {
      startDate: '14daysAgo',
      endDate: 'today',
    },
  ];

  const req = {
    reportRequests: [
      {
        viewId,
        dateRanges,
        metrics,
        dimensions,
        orderBys,
      },
    ],
  };

  // Pull report and output the data
  return analytics.reports.batchGet({
    auth: jwtClient,
    resource: req,
  });
};
