import * as moment from 'moment';
import { ArticleStatuses, IArticleCreate } from '../../shared/types/article';
import upload from '../api/s3';
import { articleModel } from '../model/article';
import { getCategory } from '../model/category';
import { slugify } from '../utils';

export default async ({
  title,
  categoryId,
  userId,
  text,
  type,
  image,
  video,
}: IArticleCreate) => {
  const slug = slugify(title);
  let uploaded;

  if (image) {
    const { createReadStream } = await image;
    const stream = createReadStream();
    uploaded = await upload(stream);
  }

  if (categoryId && !(await getCategory(categoryId))) {
    throw new Error('Kategorie neexistuje');
  } else {
    return articleModel.create({
      title,
      slug,
      text,
      type,
      categoryId,
      userId,
      createdDateTime: moment(),
      status: ArticleStatuses.new,
      ...(uploaded && { image: uploaded.Location }),
      ...(video && { video }),
    });
  }
};
