import {
  ArticleStatuses,
  IArticle,
  IArticleEdit,
} from '../../shared/types/article';
import upload from '../api/s3';
import { articleModel } from '../model/article';
import { slugify } from '../utils';
import getArticleById from './getArticleById';

export default async (editedArticle: IArticleEdit): Promise<IArticle> => {
  const slug = slugify(editedArticle.title);

  let uploaded;
  if (editedArticle.image) {
    const { createReadStream } = await editedArticle.image;
    const stream = createReadStream();
    uploaded = await upload(stream);
  }

  const article = await getArticleById(editedArticle._id);

  const updated = await articleModel.findByIdAndUpdate(
    editedArticle._id,
    {
      ...editedArticle,
      slug,
      ...(uploaded && { image: uploaded.Location }),
      ...(article.status !== ArticleStatuses.published && {
        status: ArticleStatuses.updated,
      }),
    },
    { new: true },
  );

  return updated;
};
