import * as moment from 'moment';
import { ArticleStatuses, ArticleTypes } from '../../shared/types/article';
import { articleModel } from '../model/article';
import { slugify } from '../utils';

const loremIpsum = require('lorem-ipsum');
const getRandomFromArray = (arr: any[]) =>
  arr[Math.floor(Math.random() * arr.length)];

export default async (request: any, response: any) => {
  try {
    for (let i = 1; i < 10; i = i + 1) {
      const title = loremIpsum({ count: 6, units: 'words' });
      const text = loremIpsum({ count: 5, units: 'paragraphs' });
      const type = getRandomFromArray([
        ArticleTypes.zakulisi,
        ArticleTypes.prehledy,
        ArticleTypes.recenze,
      ]);
      const status = getRandomFromArray([
        ArticleStatuses.new,
        ArticleStatuses.updated,
        ArticleStatuses.rejected,
        ArticleStatuses.published,
      ]);
      const categoryId =
        type === ArticleTypes.recenze
          ? getRandomFromArray([
              '5c39abe8d2159826193fd7e8',
              '5c39abecd2159826193fd7e9',
              '5c39abf1d2159826193fd7ea',
              '5c39abf9d2159826193fd7eb',
              '5c39abfed2159826193fd7ec',
              '5c39ac0bd2159826193fd7ed',
              '5c39ac15d2159826193fd7ee',
            ])
          : undefined;

      const userId = getRandomFromArray([
        'e3b64cae-3db3-4969-a9f0-ddec9547b8f0',
        '066a4cb8-b9b1-4bc8-8aef-9f443d0edc03',
        '6bb79794-4523-46ef-8975-635e7ecc41a2',
        '9c193bcb-adc9-444d-96fd-0755fcad0bad',
      ]);
      await articleModel.create({
        userId,
        status,
        slug: slugify(title),
        title,
        text,
        categoryId,
        type,
        image: `https://picsum.photos/1200/480?image=${Math.floor(
          Math.random() * 200,
        )}`,
        createdDateTime: moment(),
      });
    }

    response.send('OK');
  } catch (e) {
    response.status(500);
    response.send(e.message);
  }
};
