import { GraphQLInt, GraphQLNonNull, GraphQLString } from 'graphql';
import { ArticleStatuses, IArticle } from '../../../../shared/types/article';
import { changeArticleStatusPermissions } from '../../../../shared/types/permissions';
import { isAuthorized } from '../../../api/cognito';
import changeArticleStatus from '../../../articles/changeArticleStatus';
import GraphqlArticle from '../outputs/Article';

interface IArgs {
  _id: string;
  status: ArticleStatuses;
}

export default {
  type: GraphqlArticle,
  args: {
    _id: {
      type: new GraphQLNonNull(GraphQLString),
    },
    status: {
      type: new GraphQLNonNull(GraphQLInt),
    },
  },
  resolve: async (
    parent: any,
    { _id, status }: IArgs,
    request: Request,
  ): Promise<IArticle> => {
    isAuthorized(request, changeArticleStatusPermissions);
    return changeArticleStatus(_id, status);
  },
};
