import {
  GraphQLFloat,
  GraphQLID,
  GraphQLInt,
  GraphQLList,
  GraphQLObjectType,
  GraphQLString,
} from 'graphql';
import { GraphQLDateTime } from 'graphql-iso-date';
import { IArticleDb } from '../../../../shared/types/article';
import { getCategory } from '../../../model/category';
import { getComments } from '../../../model/comment';
import getAverageScore from '../../../scores/getAverageScore';
import { GraphQLCategory } from '../../categories';
import { GraphQLComment } from '../../comments';
import { GraphQLUser } from '../../users';
import getUser from '../../users/lib/getUser';

export default new GraphQLObjectType({
  name: 'Article',
  fields: {
    _id: {
      type: GraphQLID,
    },
    title: {
      type: GraphQLString,
    },
    slug: {
      type: GraphQLString,
    },
    category: {
      type: GraphQLCategory,
      resolve: async ({ categoryId }: IArticleDb) => getCategory(categoryId),
    },
    image: {
      type: GraphQLString,
    },
    video: {
      type: GraphQLString,
    },
    text: {
      type: GraphQLString,
    },
    createdDateTime: {
      type: GraphQLDateTime,
    },
    type: {
      type: GraphQLInt,
    },
    status: {
      type: GraphQLInt,
    },
    user: {
      type: GraphQLUser,
      resolve: async (article: IArticleDb) => getUser(article.userId),
    },
    comments: {
      type: new GraphQLList(GraphQLComment),
      resolve: async ({ _id }: IArticleDb) => getComments(_id),
    },
    averageScore: {
      description: 'Average of user score',
      type: GraphQLFloat,
      resolve: async ({ _id }: IArticleDb) => getAverageScore(_id),
    },
  },
});
