import { GraphQLNonNull, GraphQLString } from 'graphql';
import { createCategoryPermissions } from '../../../../shared/types/permissions';
import { isAuthorized } from '../../../api/cognito';
import { categoryModel, getNewCategoryIndex } from '../../../model/category';
import { slugify } from '../../../utils';
import GraphQLCategory from '../outputs/Category';

interface IArgs {
  title: string;
}

export default {
  type: GraphQLCategory,
  args: {
    title: {
      type: new GraphQLNonNull(GraphQLString),
    },
  },
  resolve: async (_: any, { title }: IArgs, request: Request): Promise<any> => {
    try {
      isAuthorized(request, createCategoryPermissions);
      const slug = slugify(title);
      const index = await getNewCategoryIndex();

      return categoryModel.create({
        title,
        slug,
        index,
      });
    } catch (e) {
      throw new Error(e.message);
    }
  },
};
