import { GraphQLInt, GraphQLList, GraphQLNonNull } from 'graphql';
import { arrayMove } from 'react-sortable-hoc';
import { ICategory } from '../../../../shared/types/category';
import { sortCategoriesPermissions } from '../../../../shared/types/permissions';
import { isAuthorized } from '../../../api/cognito';
import { categoryModel, getCategories } from '../../../model/category';
import GraphQLCategory from '../outputs/Category';

export default {
  type: new GraphQLList(GraphQLCategory),
  args: {
    oldIndex: {
      type: new GraphQLNonNull(GraphQLInt),
    },
    newIndex: {
      type: new GraphQLNonNull(GraphQLInt),
    },
  },
  resolve: async (
    parent: any,
    { oldIndex, newIndex }: any,
    request: Request,
  ): Promise<ICategory[]> => {
    isAuthorized(request, sortCategoriesPermissions);
    const categories = await getCategories();
    const data = arrayMove(categories, oldIndex, newIndex);

    data.forEach(async ({ _id }, i) => {
      await categoryModel.updateOne({ _id }, { index: i });
    });

    return getCategories();
  },
};
