import { GraphQLInt, GraphQLNonNull, GraphQLString } from 'graphql';
import { scorePermission } from '../../../../shared/types/permissions';
import { ICreateScore, IScoreDb } from '../../../../shared/types/score';
import { isAuthorized } from '../../../api/cognito';
import createScore from '../../../scores/createScore';
import getCurrentUserId from '../../users/lib/getCurrentUserId';
import GraphQLScore from '../outputs/Score';

export default {
  type: GraphQLScore,
  args: {
    value: {
      type: new GraphQLNonNull(GraphQLInt),
    },
    itemId: {
      type: new GraphQLNonNull(GraphQLString),
    },
  },
  resolve: async (
    parent: any,
    { value, itemId }: ICreateScore,
    request: Request,
  ): Promise<IScoreDb> => {
    isAuthorized(request, scorePermission);
    const userId = await getCurrentUserId(request);
    return createScore({ value, itemId, userId });
  },
};
