import { GraphQLNonNull, GraphQLString } from 'graphql';
import { scorePermission } from '../../../../shared/types/permissions';
import { IScoreDb } from '../../../../shared/types/score';
import { isAuthorized } from '../../../api/cognito';
import deleteScore from '../../../scores/deleteScore';
import getCurrentUserId from '../../users/lib/getCurrentUserId';
import { GraphQLScore } from '../index';

interface IArgs {
  itemId: string;
}

export default {
  type: GraphQLScore,
  args: {
    itemId: {
      type: new GraphQLNonNull(GraphQLString),
    },
  },
  resolve: async (
    parent: any,
    { itemId }: IArgs,
    request: Request,
  ): Promise<IScoreDb> => {
    isAuthorized(request, scorePermission);
    const userId = await getCurrentUserId(request);
    return deleteScore({ itemId, userId });
  },
};
