import * as AWS from 'aws-sdk';
import { GroupType } from 'aws-sdk/clients/cognitoidentityserviceprovider';
import { UserPoolId } from '../../../index';

export const setGroups = async (Username: string, groups: string[]) => {
  const Pool = new AWS.CognitoIdentityServiceProvider();
  return Promise.all(
    groups.map((GroupName: string) =>
      Pool.adminAddUserToGroup({
        Username,
        UserPoolId,
        GroupName,
      }).promise(),
    ),
  )
    .then((data: any) => data)
    .catch((err: any) => {
      throw new Error(`"A user's groups could not be updated: ", ${err}`);
    });
};

export const getGroups = async (Username: string) => {
  const Pool = new AWS.CognitoIdentityServiceProvider();

  const params = {
    UserPoolId,
    Username,
  };

  const groupListData = await Pool.adminListGroupsForUser(params).promise();

  const currentGroupList =
    groupListData.Groups &&
    (groupListData.Groups.map(
      (Group: GroupType) => Group.GroupName,
    ) as string[]);

  return currentGroupList;
};
