import * as AWS from 'aws-sdk';
import { UserType } from 'aws-sdk/clients/cognitoidentityserviceprovider';
import { GraphQLNonNull, GraphQLString } from 'graphql';
import errorCodes from '../../../errorCodes';
import { UserPoolId } from '../../../index';
import GraphQLUserGroup from '../inputs/UserGroup';
import { setGroups } from '../lib/groups';
import GraphQLUser from '../outputs/User';
import { generateCreateUserParams } from './helpers';

export default {
  type: GraphQLUser,
  args: {
    username: {
      type: new GraphQLNonNull(GraphQLString),
    },
    email: {
      type: new GraphQLNonNull(GraphQLString),
    },
    role: {
      type: new GraphQLNonNull(GraphQLUserGroup),
    },
    expirationDateTime: {
      type: GraphQLString,
    },
  },
  resolve: async (
    _: any,
    { username, email, role, expirationDateTime }: any,
    { userDetails }: any,
  ): Promise<UserType | undefined> => {
    const params = generateCreateUserParams(
      username,
      email,
      UserPoolId,
      expirationDateTime,
    );
    try {
      const Pool = new AWS.CognitoIdentityServiceProvider();
      const createdUser = await Pool.adminCreateUser(params).promise();
      await setGroups(username, [role]);

      return createdUser.User;
    } catch (error) {
      throw new Error(errorCodes(error));
    }
  },
};
