import * as AWS from 'aws-sdk';
import { UserType } from 'aws-sdk/clients/cognitoidentityserviceprovider';
import { GraphQLNonNull, GraphQLString } from 'graphql';
import { UserPoolId } from '../../../index';
import GraphQLUserGroup from '../inputs/UserGroup';
import GraphQLUser from '../outputs/User';
import {
  generateDeleteUserAttributeParams,
  generateEditUserParams,
} from './helpers';

export default {
  type: GraphQLUser,
  args: {
    username: {
      type: new GraphQLNonNull(GraphQLString),
    },
    role: {
      type: new GraphQLNonNull(GraphQLUserGroup),
    },
    expirationDateTime: {
      type: GraphQLString,
    },
  },
  resolve: async (
    _: any,
    { username, role, expirationDateTime }: any,
    { userDetails }: any,
  ): Promise<UserType> => {
    const params = {
      UserPoolId,
      Username: username,
    };
    const Pool = new AWS.CognitoIdentityServiceProvider();
    await Pool.adminListGroupsForUser(params, async (err, data) => {
      if (!err && data && data.Groups) {
        data.Groups.map(async group => {
          if (group.GroupName) {
            await Pool.adminRemoveUserFromGroup({
              ...params,
              GroupName: group.GroupName,
            }).promise();
          }
        });
      }
    }).promise();

    if (expirationDateTime) {
      await Pool.adminUpdateUserAttributes(
        generateEditUserParams(username, expirationDateTime, UserPoolId),
      ).promise();
    } else {
      await Pool.adminDeleteUserAttributes(
        generateDeleteUserAttributeParams(username, UserPoolId, [
          'custom:expirationDate',
        ]),
      ).promise();
    }

    await Pool.adminAddUserToGroup(
      {
        ...params,
        GroupName: role,
      },
      error => {
        if (error) {
          throw Error(error.message);
        }
      },
    ).promise();

    return Pool.adminGetUser(params).promise();
  },
};
