import * as AWS from 'aws-sdk';
import { UserType } from 'aws-sdk/clients/cognitoidentityserviceprovider';
import { GraphQLNonNull, GraphQLString } from 'graphql';
import { UserPoolId } from '../../../index';
import GraphQLUser from '../outputs/User';

export default {
  type: GraphQLUser,
  args: {
    username: {
      type: new GraphQLNonNull(GraphQLString),
    },
  },
  resolve: async (
    _: any,
    { username }: any,
    { userDetails }: any,
  ): Promise<UserType | undefined> => {
    const params = {
      UserPoolId,
      Username: username,
    };

    try {
      const Pool = new AWS.CognitoIdentityServiceProvider();
      const userData = Pool.adminGetUser(params, async err => {
        if (!err) {
          await Pool.adminDeleteUser(params).promise();
        }
      }).promise();

      return userData;
    } catch (error) {
      throw new Error(error);
    }
  },
};
