import * as AWS from 'aws-sdk';
import { UserType } from 'aws-sdk/clients/cognitoidentityserviceprovider';
import { GraphQLNonNull, GraphQLString } from 'graphql';
import { UserPoolId } from '../../../index';
import findEmailInAttributes from '../lib/findEmailInAttributes';
import { getGroups, setGroups } from '../lib/groups';
import GraphQLUser from '../outputs/User';
import { generateCreateUserParams } from './helpers';

export default {
  type: GraphQLUser,
  args: {
    username: {
      type: new GraphQLNonNull(GraphQLString),
    },
  },
  resolve: async (
    _: any,
    { username, role }: any,
    { userDetails }: any,
  ): Promise<UserType | undefined> => {
    const params = {
      UserPoolId,
      Username: username,
    };

    try {
      const Pool = new AWS.CognitoIdentityServiceProvider();

      // fetch existing data
      const userData = await Pool.adminGetUser(params).promise();
      const groups = await getGroups(username);

      // @ts-ignore
      const email = findEmailInAttributes(userData.UserAttributes);

      // remove the user
      if (userData) {
        await Pool.adminDeleteUser(params).promise();
      }

      const createdUser = await Pool.adminCreateUser(
        // @ts-ignore
        generateCreateUserParams(username, email, UserPoolId),
      ).promise();

      if (groups && groups.length > 0) {
        await setGroups(username, groups);
      }

      return createdUser.User;
    } catch (error) {
      throw new Error(error);
    }
  },
};
