import * as AWS from 'aws-sdk';
import {
  GraphQLBoolean,
  GraphQLID,
  GraphQLObjectType,
  GraphQLString,
} from 'graphql';
import { GraphQLDateTime } from 'graphql-iso-date';
import { UserPoolId } from '../../../index';
import GraphQLUserGroup from '../inputs/UserGroup';
import findEmailInAttributes from '../lib/findEmailInAttributes';
import findExpirationDateInAttributes from '../lib/findExpirationDateInAttributes';
import findSubInAttributes from '../lib/findSubInAttributes';

export default new GraphQLObjectType({
  name: 'User',
  fields: {
    id: {
      type: GraphQLID,
      resolve: ({ Attributes, UserAttributes }: any): string | null => {
        if (Attributes) {
          return findSubInAttributes(Attributes);
        }

        if (UserAttributes) {
          return findSubInAttributes(UserAttributes);
        }

        return null;
      },
    },
    username: {
      type: GraphQLString,
      resolve: ({ Username }: any): string => Username,
    },
    createdDateTime: {
      type: GraphQLDateTime,
      resolve: ({ UserCreateDate }: any): string => UserCreateDate,
    },
    modifiedDateTime: {
      type: GraphQLDateTime,
      resolve: ({ UserLastModifiedDate }: any): string | undefined =>
        UserLastModifiedDate,
    },
    expirationDateTime: {
      type: GraphQLDateTime,
      resolve: ({ Attributes, UserAttributes }: any): Date | null => {
        let expirationDateTime = null;
        if (Attributes) {
          expirationDateTime = findExpirationDateInAttributes(Attributes);
        }

        if (UserAttributes) {
          expirationDateTime = findExpirationDateInAttributes(UserAttributes);
        }

        return expirationDateTime ? new Date(expirationDateTime) : null;
      },
    },
    isActive: {
      type: GraphQLBoolean,
      resolve: ({ Enabled }: any): boolean => Enabled,
    },
    status: {
      type: GraphQLString,
      resolve: ({ UserStatus }: any): string => UserStatus,
    },
    email: {
      type: GraphQLString,
      resolve: ({ Attributes, UserAttributes }: any): string | null => {
        if (Attributes) {
          return findEmailInAttributes(Attributes);
        }

        if (UserAttributes) {
          return findEmailInAttributes(UserAttributes);
        }

        return null;
      },
    },
    role: {
      type: GraphQLUserGroup,
      resolve: async ({ Username }: any): Promise<string | undefined> => {
        const Pool = new AWS.CognitoIdentityServiceProvider();
        const { Groups } = await Pool.adminListGroupsForUser({
          UserPoolId,
          Username,
        }).promise();

        if (Groups && Groups[0] && Groups[0].GroupName) {
          return Groups[0].GroupName;
        }

        return;
      },
    },
  },
});
