import { ICategory } from '../../shared/types/category';

const mongoose = require('mongoose');

// schema
export const categorySchema = new mongoose.Schema({
  title: String,
  slug: String,
  index: Number,
});

mongoose.model('Category', categorySchema);
export const categoryModel = mongoose.model('Category');

// queries
export const getCategories = async (conditions?: object) =>
  categoryModel.find(conditions || {}).sort({ index: 1 });
export const getCategory = async (id: string) => categoryModel.findById(id);

export const getCategoryBySlug = async (slug: string): Promise<ICategory> =>
  categoryModel.findOne({ slug });

export const deleteCategory = async (id: string) => {
  const category = await categoryModel.findByIdAndDelete(id);
  if (!category) {
    throw new Error('Kategorie nenalezena');
  }
  return category._id;
};

export const getNewCategoryIndex = async (): Promise<number> => {
  const lastCategory = await categoryModel.findOne({}).sort({ index: -1 });
  return lastCategory ? lastCategory.index + 1 : 0;
};
