import { APP_DEFAULT_PORT } from '../shared/config';
const express = require('express');
const mongoose = require('mongoose');
const enforce = require('express-sslify');
const frameguard = require('frameguard');
import * as graphqlHTTP from 'express-graphql';
import expressPlayground from 'graphql-playground-middleware-express';
import { graphqlUploadExpress } from 'graphql-upload';
import generateArticles from './generator/generateArticles';
import Schema from './gql/Schema';
import Router from './router';

const app = express();

if (app.get('env') === 'production') {
  app.use(enforce.HTTPS({ trustProtoHeader: true }));
}
app.use(frameguard({ action: 'deny' }));

app.use(express.static('dist'));

app.use(
  '/graphql',
  graphqlUploadExpress({ maxFileSize: 10000000, maxFiles: 10 }),
  graphqlHTTP({ schema: Schema }),
);

app.get('/generate-articles', generateArticles);
app.get('/playground', expressPlayground({ endpoint: '/graphql' }), () => {}); // tslint:disable-line

app.use('/', Router);

const port = Number(process.env.PORT || APP_DEFAULT_PORT);

app.listen(port, () => {
  console.log(`Express server listening on port ${port}`);
  mongoose.connect(process.env.MONGODB_URI || 'mongodb://localhost/kukr');
});
