import * as React from 'react';
import { ApolloProvider } from 'react-apollo';
import { connect } from 'react-redux';
import { selectToken } from './modules/auth/reducer';
import { IState } from './types';

import { InMemoryCache } from 'apollo-cache-inmemory';
import { ApolloClient } from 'apollo-client';
import { ApolloLink } from 'apollo-link';
import { onError } from 'apollo-link-error';
import { createUploadLink } from 'apollo-upload-client';
import { GRAPHQL_ENDPOINT } from '../shared/config';

declare const window: any;

const ApolloClientWrapper = ({ children, token }: any) => {
  const client = new ApolloClient({
    link: ApolloLink.from([
      onError(({ graphQLErrors, networkError }) => {
        if (graphQLErrors) {
          graphQLErrors.map(({ message, locations, path }) =>
            console.log(
              `[GraphQL error]: Message: ${message}, Location: ${locations}, Path: ${path}`,
            ),
          );
        }
        if (networkError) {
          console.log(`[Network error]: ${networkError}`);
        }
      }),
      createUploadLink({
        uri: GRAPHQL_ENDPOINT,
        credentials: 'same-origin',
        headers: {
          Authorization: token ? `Bearer ${token}` : '',
        },
      }),
    ]),
    cache: new InMemoryCache().restore(window.__APOLLO_STATE__),
  });

  return <ApolloProvider client={client}>{children}</ApolloProvider>;
};

export default connect(
  (state: IState) => ({
    token: selectToken(state),
  }),
  {},
)(ApolloClientWrapper);
