import { UploadFile } from 'antd/lib/upload/interface';
import { useCallback, useState } from 'react';

export const useBoolean = (initial: boolean) => {
  const [value, setValue] = useState(initial);

  return {
    setFalse: useCallback(() => setValue(false), []),
    setTrue: useCallback(() => setValue(true), []),
    setValue,
    toggle: useCallback(() => setValue((v: boolean) => !v), []),
    value,
  };
};

export const useNumber = (initial?: number) => {
  const [value, setValue] = useState(initial);

  return {
    setValue,
    value,
  };
};

export const useFile = (initial?: UploadFile) => {
  const [value, setValue] = useState(initial);

  return {
    setValue,
    reset: () => setValue(undefined),
    value,
  };
};

interface IPagination {
  total: number;
  pageSize: number;
  current: number;
}

export const usePagination = (initial: IPagination) => {
  const [value, setValue] = useState(initial);

  return {
    setValue,
    start: (value.current - 1) * value.pageSize,
    limit: value.pageSize,
    value,
  };
};
