import { connectRouter, routerMiddleware } from 'connected-react-router';
import { applyMiddleware, combineReducers, createStore, Reducer } from 'redux';
import createSagaMiddleware from 'redux-saga';

import { History } from 'history';
import authReducer from './modules/auth/reducer';
import { IState } from './types';

const rootReducer = (history: History): Reducer<IState> =>
  combineReducers({
    router: connectRouter(history),
    authReducer,
  });

export default (
  preloadedState: any,
  history: History,
  composeEnhancers: any,
) => {
  const sagaMiddleware = createSagaMiddleware();
  const router = routerMiddleware(history);
  return {
    ...createStore(
      rootReducer(history),
      preloadedState,
      composeEnhancers(
        applyMiddleware(sagaMiddleware),
        applyMiddleware(router),
      ),
    ),
    runSaga: sagaMiddleware.run,
  };
};
