import { ConnectedRouter } from 'connected-react-router';
import { createBrowserHistory } from 'history';
import * as React from 'react';
import * as ReactDOM from 'react-dom';
import * as ReactGA from 'react-ga';
import { HelmetProvider } from 'react-helmet-async';
import { Provider } from 'react-redux';
import { compose } from 'redux';
import getSaga from './getSaga';
import getStore from './getStore';
import App from './modules/app/App';

import ApolloClientWrapper from './ApolloClientWrapper';
import './index.css';

declare const window: any;

const preloaded = window.__REDUX_STATE__;
delete window.__REDUX_STATE__;

const history = createBrowserHistory();
const composeEnhancers = window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__ || compose;

const store = getStore(preloaded, history, composeEnhancers);

store.runSaga(getSaga());

ReactGA.initialize('UA-43645019-21');

history.listen(location => {
  ReactGA.set({ page: location.pathname });
  ReactGA.pageview(location.pathname);
});

ReactDOM.hydrate(
  (
    <HelmetProvider>
      <Provider store={store}>
        <ApolloClientWrapper>
          <ConnectedRouter history={history}>
            <App />
          </ConnectedRouter>
        </ApolloClientWrapper>
      </Provider>
    </HelmetProvider>
  ) as any,
  document.getElementById('root') as HTMLElement,
);
