import Icon from 'antd/lib/icon';
import Menu from 'antd/lib/menu';
import * as React from 'react';
import { connect } from 'react-redux';
import { Route, Switch } from 'react-router-dom';
import styled from 'styled-components';
import {
  articleAvailablePermissions,
  categoryAvailablePermissions,
  editorsAvailablePermissions,
  reportsAvailablePermissions,
  usersAvailablePermissions,
} from '../../../shared/types/permissions';
import { IState } from '../../types';
import { selectHasPermission, selectIsLoading } from '../auth/reducer';
import Loader from '../components/Loader';
import withRouter from '../hoc/withRouter';
import { Routes } from '../router/routes';
import ArticleList from './article/list/ArticleList';
import CategoryList from './category/list/CategoryList';
import Editors from './editors/Editors';
import Reports from './reports/Reports';
import UserList from './users/list/UserList';

const Content = styled.div`
  padding: 10px 20px;
`;
const Wrapper = styled.div`
  background-color: #fff;
  min-height: 100vh;
`;

const modules = [
  {
    label: 'Mé Články',
    component: ArticleList,
    permissions: articleAvailablePermissions,
    path: Routes.articles,
  },
  {
    label: 'Redakce',
    component: Editors,
    permissions: editorsAvailablePermissions,
    path: Routes.editors,
  },
  {
    label: 'Kategorie',
    component: CategoryList,
    permissions: categoryAvailablePermissions,
    path: Routes.categories,
  },
  {
    label: 'Přehledy',
    component: Reports,
    permissions: reportsAvailablePermissions,
    path: Routes.reports,
  },
  {
    label: 'Uživatelé',
    component: UserList,
    permissions: usersAvailablePermissions,
    path: Routes.users,
  },
];

const Dashboard = ({ children, push, isLoading, hasPermission }: any) => {
  if (isLoading) {
    return <Loader />;
  }

  const modulesWithPermission = modules.filter(module =>
    hasPermission(module.permissions),
  );

  const handleClick = ({ key }: any) => push(key);

  return (
    <Wrapper>
      <Menu onClick={handleClick} selectedKeys={[]} mode="horizontal">
        <Menu.Item key={Routes.home}>
          <Icon type="left" />
        </Menu.Item>
        {modulesWithPermission.map(module => (
          <Menu.Item key={module.path}>{module.label}</Menu.Item>
        ))}
      </Menu>

      <Content>
        <Switch>
          {modulesWithPermission.map(module => (
            <Route
              key={module.path}
              path={module.path}
              component={module.component}
            />
          ))}
        </Switch>
      </Content>
    </Wrapper>
  );
};

export default connect(
  (state: IState) => ({
    hasPermission: selectHasPermission(state),
    isLoading: selectIsLoading(state),
  }),
  {},
)(withRouter(Dashboard));
