import Button from 'antd/lib/button';
import Form, { FormComponentProps } from 'antd/lib/form';
import Icon from 'antd/lib/icon';
import Input from 'antd/lib/input';
import Radio from 'antd/lib/radio';
import Upload from 'antd/lib/upload';
import * as React from 'react';
import { ArticleTypes, IArticle } from '../../../../../shared/types/article';
import { useFile, useNumber } from '../../../../customHooks';
import ReactQuill from '../../../components/ReactQuill';
import RULES from '../../../form/rules';
import SelectArticleCategory from './SelectArticleCategory';
const get = require('lodash/get');

interface IProps extends FormComponentProps {
  handleBeforeUpload: any;
  article?: IArticle;
}

const ArticleFormFields = ({ form, article, handleBeforeUpload }: IProps) => {
  const currentArticleType = useNumber(get(article, 'type'));
  const file = useFile();

  const handleTypeChange = (e: any) => {
    currentArticleType.setValue(e.target.value);
  };

  return (
    <React.Fragment>
      <Form.Item label="Název">
        {form.getFieldDecorator('title', {
          rules: RULES.ARTICLE_TITLE.rules,
          initialValue: get(article, 'title'),
        })(
          currentArticleType.value !== ArticleTypes.aktualne ? (
            <Input />
          ) : (
            <Input.TextArea />
          ),
        )}
      </Form.Item>

      {currentArticleType.value !== ArticleTypes.aktualne && (
        <React.Fragment>
          <Form.Item>
            {article && article.image && (
              <img
                src={article.image}
                style={{ width: '50px', marginRight: '20px' }}
              />
            )}
            {form.getFieldDecorator(
              'image',
              !get(article, 'image') ? RULES.ARTICLE_IMAGE : {},
            )(
              <Upload
                beforeUpload={handleBeforeUpload}
                fileList={file.value ? [file.value] : []}
              >
                <Button>
                  <Icon type="upload" /> Vybrat obrázek
                </Button>
              </Upload>,
            )}
          </Form.Item>

          <Form.Item label="ID youtube videa">
            {form.getFieldDecorator('video', {
              initialValue: get(article, 'video'),
            })(<Input />)}
          </Form.Item>
        </React.Fragment>
      )}

      <Form.Item label="Typ">
        {form.getFieldDecorator('type', {
          rules: RULES.ARTICLE_TYPE.rules,
          initialValue: get(article, 'type'),
        })(
          <Radio.Group buttonStyle="solid" onChange={handleTypeChange}>
            <Radio.Button value={ArticleTypes.zakulisi}>Zákulisí</Radio.Button>
            <Radio.Button value={ArticleTypes.recenze}>Recenze</Radio.Button>
            <Radio.Button value={ArticleTypes.prehledy}>Přehledy</Radio.Button>
            <Radio.Button value={ArticleTypes.aktualne}>Aktuálně</Radio.Button>
          </Radio.Group>,
        )}
      </Form.Item>

      {currentArticleType.value === ArticleTypes.recenze && (
        <SelectArticleCategory form={form} article={article} />
      )}

      {currentArticleType.value !== ArticleTypes.aktualne && (
        <Form.Item label="Text">
          {form.getFieldDecorator('text', {
            initialValue: get(article, 'text'),
          })(<ReactQuill />)}
        </Form.Item>
      )}
    </React.Fragment>
  );
};
export default ArticleFormFields;
