import Form from 'antd/lib/form';
import { WrappedFormUtils } from 'antd/lib/form/Form';
import Select from 'antd/lib/select';
import * as React from 'react';
import { Query } from 'react-apollo';
import { IArticle } from '../../../../../shared/types/article';
import { ICategory } from '../../../../../shared/types/category';
import RULES from '../../../form/rules';
import { SETTINGS_CATEGORIES } from '../../queries';

const get = require('lodash/get');

interface IProps {
  form: WrappedFormUtils;
  article?: IArticle;
}

const SelectArticleCategory = ({ form, article }: IProps) => (
  <Query query={SETTINGS_CATEGORIES}>
    {({ loading, error, data }) => {
      if (loading || error) {
        return null; // TODO: loader
      }

      return (
        <Form.Item label="Kategorie">
          {form.getFieldDecorator('categoryId', {
            rules: RULES.ARTICLE_CATEGORY.rules,
            initialValue: article ? get(article, 'category._id') : undefined,
          })(
            <Select
              showSearch={true}
              placeholder="Zvolte kategorii"
              optionFilterProp="children"
            >
              {data.categories.map((c: ICategory) => (
                <Select.Option key={c._id} value={c._id}>
                  {c.title}
                </Select.Option>
              ))}
            </Select>,
          )}
        </Form.Item>
      );
    }}
  </Query>
);

export default SelectArticleCategory;
