import * as React from 'react';
import { Mutation } from 'react-apollo';
import { connect } from 'react-redux';
import { createArticlePermissions } from '../../../../../shared/types/permissions';
import { IState } from '../../../../types';
import { selectHasPermission, selectIsLoading } from '../../../auth/reducer';
import { limit } from '../../../components/LoadMoreTable';
import Spin from '../../../components/Spin';
import { SETTINGS_USER_ARTICLES } from '../../queries';
import { CREATE_ARTICLE } from '../mutations';
import CreateArticleForm from './CreateArticleForm';

interface IProps {
  hasPermission: (groups: string[]) => boolean;
  isLoading: boolean;
}

const CreateArticle = ({ hasPermission, isLoading }: IProps) => {
  if (!hasPermission(createArticlePermissions)) {
    return null;
  }

  if (isLoading) {
    return <Spin size={14} />;
  }

  return (
    <Mutation
      mutation={CREATE_ARTICLE}
      refetchQueries={[
        {
          query: SETTINGS_USER_ARTICLES,
          variables: { start: 0, limit },
        },
      ]}
    >
      {(createArticle, { loading }) => (
        <CreateArticleForm createArticle={createArticle} loading={loading} />
      )}
    </Mutation>
  );
};

export default connect(
  (state: IState) => ({
    hasPermission: selectHasPermission(state),
    isLoading: selectIsLoading(state),
  }),
  {},
)(CreateArticle);
