import Button from 'antd/lib/button';
import Form from 'antd/lib/form';
import { FormComponentProps } from 'antd/lib/form/Form';
import message from 'antd/lib/message';
import Modal from 'antd/lib/modal';
import { UploadFile } from 'antd/lib/upload/interface';
import * as React from 'react';
import { useBoolean, useFile } from '../../../../customHooks';
import ArticleFormFields from '../components/ArticleFormFields';

interface IProps extends FormComponentProps {
  createArticle: any;
  loading: boolean;
}

const CreateArticleForm = ({ form, createArticle, loading }: IProps) => {
  const isVisible = useBoolean(false);
  const file = useFile();

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    form.validateFieldsAndScroll(async (err: any, values: any) => {
      if (!err) {
        try {
          const { categoryId } = values;
          const createdUser = await createArticle({
            variables: {
              data: {
                title: values.title,
                image: file.value,
                text: values.text,
                type: values.type,
                video: values.video,
                categoryId,
              },
            },
          });

          if (createdUser) {
            message.success('Článek vytvořen');
            form.resetFields();
            file.reset();
            isVisible.setFalse();
          }
        } catch (e) {
          message.error(e.message);
          form.resetFields();
          isVisible.setFalse();
        }
      }
    });
  };

  const handleBeforeUpload = (f: UploadFile) => {
    file.setValue(f);
    return false;
  };

  return (
    <React.Fragment>
      <Button icon="add" onClick={isVisible.setTrue} style={{ margin: 10 }}>
        Vytvořit článek
      </Button>

      <Modal
        title="Nový článek"
        visible={isVisible.value}
        onOk={handleSubmit}
        okText="Uložit"
        width="90%"
        style={{ top: 20 }}
        onCancel={isVisible.setFalse}
        confirmLoading={loading}
        destroyOnClose={true}
      >
        <Form onSubmit={handleSubmit}>
          <ArticleFormFields
            handleBeforeUpload={handleBeforeUpload}
            form={form}
          />
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default Form.create()(CreateArticleForm);
