import * as React from 'react';
import { Mutation } from 'react-apollo';
import { connect } from 'react-redux';
import { ArticleStatuses, IArticle } from '../../../../../shared/types/article';
import { editArticlePermissions } from '../../../../../shared/types/permissions';
import { IState } from '../../../../types';
import { selectHasPermission, selectIsLoading } from '../../../auth/reducer';
import Spin from '../../../components/Spin';
import { EDIT_ARTICLE } from '../mutations';
import EditArticleForm from './EditArticleForm';

interface IProps {
  article: IArticle;
  hasPermission: (groups: string[]) => boolean;
  isLoading: boolean;
}

const EditArticle = ({ hasPermission, isLoading, article }: IProps) => {
  if (
    !hasPermission(editArticlePermissions) ||
    article.status === ArticleStatuses.published
  ) {
    return null;
  }

  if (isLoading) {
    return <Spin size={14} />;
  }

  return (
    <Mutation mutation={EDIT_ARTICLE}>
      {(editArticle, { loading }) => (
        <EditArticleForm
          article={article}
          editArticle={editArticle}
          loading={loading}
        />
      )}
    </Mutation>
  );
};

export default connect(
  (state: IState) => ({
    hasPermission: selectHasPermission(state),
    isLoading: selectIsLoading(state),
  }),
  {},
)(EditArticle);
