import Button from 'antd/lib/button';
import Form from 'antd/lib/form';
import { FormComponentProps } from 'antd/lib/form/Form';
import message from 'antd/lib/message';
import Modal from 'antd/lib/modal';
import { UploadFile } from 'antd/lib/upload/interface';
import * as React from 'react';
import { IArticle } from '../../../../../shared/types/article';
import { useBoolean, useFile } from '../../../../customHooks';
import ArticleFormFields from '../components/ArticleFormFields';

interface IProps extends FormComponentProps {
  editArticle: any;
  loading: boolean;
  article: IArticle;
}

const EditArticleForm = ({ form, editArticle, loading, article }: IProps) => {
  const isVisible = useBoolean(false);
  const file = useFile();

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    form.validateFieldsAndScroll(async (err: any, values: any) => {
      if (!err) {
        try {
          const { categoryId } = values;
          const data = {
            _id: article._id,
            title: values.title,
            image: file.value,
            text: values.text,
            type: values.type,
            video: values.video,
            categoryId,
          };

          const editedArticle = await editArticle({
            variables: { data },
          });

          if (editedArticle) {
            message.success('Článek upraven');
            form.resetFields();
            file.reset();
            isVisible.setFalse();
          }
        } catch (e) {
          message.error(e.message);
          form.resetFields();
          isVisible.setFalse();
        }
      }
    });
  };

  const handleBeforeUpload = (f: UploadFile) => {
    file.setValue(f);
    return false;
  };

  return (
    <React.Fragment>
      <Button
        icon="edit"
        shape="circle"
        onClick={isVisible.setTrue}
        style={{ margin: 10 }}
      />

      <Modal
        title="Úprava článku"
        visible={isVisible.value}
        onOk={handleSubmit}
        okText="Uložit"
        width="90%"
        style={{ top: 20 }}
        onCancel={isVisible.setFalse}
        confirmLoading={loading}
        destroyOnClose={true}
      >
        <Form onSubmit={handleSubmit}>
          <ArticleFormFields
            article={article}
            handleBeforeUpload={handleBeforeUpload}
            form={form}
          />
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default Form.create()(EditArticleForm);
