import * as React from 'react';
import { Query } from 'react-apollo';
import { IArticle } from '../../../../../shared/types/article';
import ArticleCategory from '../../../components/ArticleCategory';
import ArticleStatus from '../../../components/ArticleStatus';
import ErrorMessage from '../../../components/ErrorMessage';
import LoadMoreTable from '../../../components/LoadMoreTable';
import Loader from '../../editors/Editors';
import { SETTINGS_USER_ARTICLES, USER_ARTICLE_COUNT } from '../../queries';
import CreateArticle from '../create/CreateArticle';
import EditArticle from '../edit/EditArticle';
import DeleteArticleButton from './DeleteArticleButton';

const columns = [
  {
    title: 'Název',
    dataIndex: 'title',
  },
  {
    title: 'Status',
    dataIndex: 'status',
    render: (text: string, record: IArticle) => (
      <ArticleStatus value={record.status} />
    ),
  },
  {
    title: 'Kategorie',
    dataIndex: 'category.title',
    render: (text: string, record: IArticle) => (
      <ArticleCategory type={record.type} category={record.category} />
    ),
  },
  {
    title: 'Akce',
    dataIndex: '_id',
    render: (text: string, record: IArticle) => (
      <React.Fragment>
        <EditArticle article={record} />
        <DeleteArticleButton {...record} />
      </React.Fragment>
    ),
  },
];

const ArticleList = () => (
  <React.Fragment>
    <CreateArticle />
    <Query query={USER_ARTICLE_COUNT}>
      {({ loading, error, data }) => {
        if (error) {
          return <ErrorMessage message={error.message} />;
        }

        if (loading) {
          return <Loader />;
        }

        return (
          <LoadMoreTable
            rowKey="_id"
            total={data.userArticleCount}
            query={SETTINGS_USER_ARTICLES}
            dataSourceKey="userArticles"
            columns={columns}
          />
        );
      }}
    </Query>
  </React.Fragment>
);

export default ArticleList;
