import Button from 'antd/lib/button';
import message from 'antd/lib/message';
import Popconfirm from 'antd/lib/popconfirm';
import * as React from 'react';
import { Mutation } from 'react-apollo';
import { connect } from 'react-redux';
import { ArticleStatuses, IArticle } from '../../../../../shared/types/article';
import { deleteArticlePermissions } from '../../../../../shared/types/permissions';
import { IState } from '../../../../types';
import { selectHasPermission, selectIsLoading } from '../../../auth/reducer';
import { LoadMoreTableContext } from '../../../components/LoadMoreTable';
import Spin from '../../../components/Spin';
import { SETTINGS_USER_ARTICLES } from '../../queries';
import { DELETE_ARTICLE } from '../mutations';

interface IProps extends IArticle {
  hasPermission: (groups: string[]) => boolean;
  isLoading: boolean;
}

const DeleteArticleButton = ({
  _id,
  title,
  user,
  hasPermission,
  isLoading,
  status,
}: IProps) => {
  if (isLoading) {
    return <Spin size={14} />;
  }

  if (
    !hasPermission(deleteArticlePermissions) ||
    status === ArticleStatuses.published
  ) {
    return null;
  }

  const handleClick = (deleteArticle: any) => async () => {
    try {
      await deleteArticle({ variables: { _id } });
      message.success(`Článek "${title}" byl smazán`);
    } catch (e) {
      message.error(e.message);
    }
  };

  return (
    <LoadMoreTableContext.Consumer>
      {({ pagination }: any) => (
        <Mutation
          mutation={DELETE_ARTICLE}
          refetchQueries={[
            {
              query: SETTINGS_USER_ARTICLES,
              variables: { start: pagination.start, limit: pagination.limit },
            },
          ]}
        >
          {(deleteArticle, { loading }) => {
            return (
              <Popconfirm
                title="Opravdu chcete článek nevratně smazat?"
                onConfirm={handleClick(deleteArticle)}
                okText="Ano"
                cancelText="Ne"
              >
                <Button
                  type="danger"
                  shape="circle"
                  icon="delete"
                  loading={loading}
                />
              </Popconfirm>
            );
          }}
        </Mutation>
      )}
    </LoadMoreTableContext.Consumer>
  );
};

export default connect(
  (state: IState) => ({
    hasPermission: selectHasPermission(state),
    isLoading: selectIsLoading(state),
  }),
  {},
)(DeleteArticleButton);
