import Button from 'antd/lib/button';
import Form from 'antd/lib/form';
import { FormComponentProps } from 'antd/lib/form/Form';
import Input from 'antd/lib/input';
import message from 'antd/lib/message';
import Modal from 'antd/lib/modal';
import * as React from 'react';
import { MutationFn, OperationVariables } from 'react-apollo';
import { useBoolean } from '../../../../customHooks';
import RULES from '../../../form/rules';

interface IProps extends FormComponentProps {
  createCategory: MutationFn<{ title: string }, OperationVariables>;
  isLoading: boolean;
}

const CreateCategoryForm = ({ createCategory, isLoading, form }: IProps) => {
  const isVisible = useBoolean(false);

  const handleSubmit = () => {
    form.validateFieldsAndScroll(async (err, values) => {
      if (!err) {
        try {
          const createdUser = await createCategory({ variables: values });

          if (createdUser) {
            message.success('Kategorie vytvořena');
            form.resetFields();
            isVisible.setFalse();
          }
        } catch (e) {
          message.error(e.message);
          form.resetFields();
          isVisible.setFalse();
        }
      }
    });
  };

  return (
    <React.Fragment>
      <Button icon="add" onClick={isVisible.setTrue} style={{ margin: 10 }}>
        Vytvořit kategorii
      </Button>

      <Modal
        title="Nová kategorie"
        visible={isVisible.value}
        onOk={handleSubmit}
        okText="Uložit"
        onCancel={isVisible.setFalse}
        confirmLoading={isLoading}
      >
        <Form>
          <Form.Item label="Název">
            {form.getFieldDecorator('title', RULES.CATEGORY_TITLE)(<Input />)}
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default Form.create()(CreateCategoryForm);
