import Button from 'antd/lib/button';
import Icon from 'antd/lib/icon';
import AntdList from 'antd/lib/list';
import * as React from 'react';
import { Mutation } from 'react-apollo';
import {
  SortableContainer as SortableContainerHoc,
  SortableElement,
  SortableHandle,
} from 'react-sortable-hoc';
import styled from 'styled-components';
import { ICategory } from '../../../../../shared/types/category';
import ErrorMessage from '../../../components/ErrorMessage';
import Loader from '../../../components/Loader';
import { SETTINGS_CATEGORIES } from '../../queries';
import { DELETE_CATEGORY, SORT_CATEGORIES } from '../mutations';

const Handle = styled.div`
  margin-right: 10px;
`;
const ItemWrapper = styled.div`
  display: flex;
  align-items: center;
`;

interface IProps {
  categories: ICategory[];
}

const DragHandle = SortableHandle(() => (
  <Handle>
    <Icon type="drag" />
  </Handle>
));

const SortableItem = SortableElement(
  ({ category }: { category: ICategory }) => {
    const { _id } = category;

    const handleClick = (deleteCategory: any) => async () =>
      deleteCategory({ variables: { _id } });

    return (
      <Mutation
        mutation={DELETE_CATEGORY}
        refetchQueries={[{ query: SETTINGS_CATEGORIES }]}
      >
        {(deleteCategory, { loading, error }) => {
          if (loading) {
            return <Loader />;
          }

          if (error) {
            return <ErrorMessage message={error.message} />;
          }

          return (
            <AntdList.Item
              actions={[
                <Button
                  key="delete"
                  type="danger"
                  shape="circle"
                  icon="delete"
                  onClick={handleClick(deleteCategory)}
                />,
              ]}
              style={{
                zIndex: 9999,
                display: 'flex',
                alignItems: 'center',
                justifyContent: 'space-between',
              }}
            >
              <ItemWrapper>
                <DragHandle />
                {category.title}
              </ItemWrapper>
            </AntdList.Item>
          );
        }}
      </Mutation>
    );
  },
);

const SortableContainer = SortableContainerHoc(({ items }: any) => {
  const renderListItem = (category: ICategory, index: number) => (
    <SortableItem category={category} index={index} />
  );

  return (
    <AntdList
      size="small"
      bordered={true}
      renderItem={renderListItem}
      dataSource={items}
    />
  );
});

const List = ({ categories }: IProps) => (
  <Mutation
    mutation={SORT_CATEGORIES}
    refetchQueries={[{ query: SETTINGS_CATEGORIES }]}
  >
    {(sortCategories, { loading, error }) => {
      if (loading) {
        return <Loader />;
      }

      if (error) {
        return <ErrorMessage message={error.message} />;
      }

      const onSortEnd = async ({
        oldIndex,
        newIndex,
      }: {
        oldIndex: number;
        newIndex: number;
      }) => {
        sortCategories({ variables: { oldIndex, newIndex } });
      };

      return (
        <SortableContainer
          lockAxis="y"
          onSortEnd={onSortEnd}
          useDragHandle={true}
          items={categories}
        />
      );
    }}
  </Mutation>
);

export default List;
