import message from 'antd/lib/message';
import Select from 'antd/lib/select';
import * as React from 'react';
import { Mutation } from 'react-apollo';
import { ArticleStatuses, IArticle } from '../../../../shared/types/article';
import { CHANGE_ARTICLE_STATUS } from './mutations';

const Option = Select.Option;

interface IProps {
  article: IArticle;
}

const ChangeArticleStatusButton = ({ article }: IProps) => {
  const { _id, title, status } = article;
  const handleChange = (changeArticleStatus: any) => async (
    value: ArticleStatuses,
  ) => {
    try {
      await changeArticleStatus({ variables: { _id, status: value } });
      message.success(`Status článku "${title}" upraven`);
    } catch (e) {
      message.error(e.message);
    }
  };

  if (article.status === ArticleStatuses.published) {
    return <span>Zveřejněný</span>;
  }

  return (
    <Mutation mutation={CHANGE_ARTICLE_STATUS}>
      {(changeArticleStatus, { loading }) => {
        return (
          <Select
            loading={loading}
            value={status}
            style={{ width: 120 }}
            onChange={handleChange(changeArticleStatus)}
          >
            <Option value={ArticleStatuses.new} disabled={true}>
              Nový
            </Option>
            <Option value={ArticleStatuses.updated} disabled={true}>
              Upravený
            </Option>
            <Option value={ArticleStatuses.rejected}>Zamítnutý</Option>
            <Option value={ArticleStatuses.published}>Zveřejněný</Option>
          </Select>
        );
      }}
    </Mutation>
  );
};

export default ChangeArticleStatusButton;
