import Button from 'antd/lib/button';
import message from 'antd/lib/message';
import Popconfirm from 'antd/lib/popconfirm';
import * as React from 'react';
import { Mutation } from 'react-apollo';
import { IArticle } from '../../../../shared/types/article';
import { LoadMoreTableContext } from '../../components/LoadMoreTable';
import { SETTINGS_ARTICLES } from '../queries';
import { DELETE_ARTICLE } from './mutations';

interface IProps {
  article: IArticle;
}

const DeleteArticleButton = ({ article }: IProps) => {
  const { _id, title } = article;
  const handleClick = (deleteArticle: any) => async () => {
    try {
      await deleteArticle({ variables: { _id } });
      message.success(`Článek "${title}" byl smazán`);
    } catch (e) {
      message.error(e.message);
    }
  };

  return (
    <LoadMoreTableContext.Consumer>
      {({ pagination }: any) => (
        <Mutation
          mutation={DELETE_ARTICLE}
          refetchQueries={[
            {
              query: SETTINGS_ARTICLES,
              variables: { start: pagination.start, limit: pagination.limit },
            },
          ]}
        >
          {(deleteArticle, { loading, error }) => {
            return (
              <Popconfirm
                title="Opravdu chcete článek nevratně smazat?"
                onConfirm={handleClick(deleteArticle)}
                okText="Ano"
                cancelText="Ne"
              >
                <Button
                  type="danger"
                  shape="circle"
                  icon="delete"
                  loading={loading}
                />
              </Popconfirm>
            );
          }}
        </Mutation>
      )}
    </LoadMoreTableContext.Consumer>
  );
};

export default DeleteArticleButton;
