import * as React from 'react';
import { Query } from 'react-apollo';
import { IArticle } from '../../../../shared/types/article';
import ArticleCategory from '../../components/ArticleCategory';
import ErrorMessage from '../../components/ErrorMessage';
import Loader from '../../components/Loader';
import LoadMoreTable from '../../components/LoadMoreTable';
import { ARTICLE_COUNT, SETTINGS_ARTICLES } from '../queries';
import ChangeArticleStatusButton from './ChangeArticleStatusButton';
import DeleteArticleButton from './DeleteArticleButton';
import EditArticleButton from './EditArticleButton';

const columns = [
  {
    title: 'Název',
    dataIndex: 'title',
  },
  {
    title: 'Status',
    dataIndex: 'status',
    render: (text: string, article: IArticle) => (
      <ChangeArticleStatusButton article={article} />
    ),
  },
  {
    title: 'Kategorie',
    dataIndex: 'category.title',
    render: (text: string, record: IArticle) => (
      <ArticleCategory type={record.type} category={record.category} />
    ),
  },
  {
    title: 'Autor',
    dataIndex: 'user.username',
  },
  {
    title: 'Akce',
    dataIndex: '_id',
    render: (text: string, article: IArticle) => (
      <React.Fragment>
        <EditArticleButton article={article} />
        <DeleteArticleButton article={article} />
      </React.Fragment>
    ),
  },
];

const Editors = () => (
  <Query query={ARTICLE_COUNT}>
    {({ loading, error, data }) => {
      if (error) {
        return <ErrorMessage message={error.message} />;
      }

      if (loading) {
        return <Loader />;
      }

      return (
        <LoadMoreTable
          rowKey="_id"
          total={data.articleCount}
          query={SETTINGS_ARTICLES}
          dataSourceKey="articles"
          columns={columns}
        />
      );
    }}
  </Query>
);

export default Editors;
