import { Button, Form, Input, message, Modal, Radio } from 'antd';
import DatePicker from 'antd/lib/date-picker';
import { FormComponentProps } from 'antd/lib/form';
import * as React from 'react';
import { MutationFn, OperationVariables } from 'react-apollo';
import { Groups } from '../../../../../shared/types/permissions';
import { useBoolean } from '../../../../customHooks';

interface IProps extends FormComponentProps {
  createUser: MutationFn<
    { username: string; email: string; role: string },
    OperationVariables
  >;
  isLoading: boolean;
}

const CreateUserForm = ({ createUser, isLoading, form }: IProps) => {
  const isVisible = useBoolean(false);

  const handleSubmit = () => {
    form.validateFieldsAndScroll(async (err, values) => {
      if (!err) {
        try {
          const createdUser = await createUser({ variables: values });
          if (createdUser) {
            message.success('Uživatel byl úspěšně vytvořen.');
            form.resetFields();
            isVisible.setFalse();
          }
        } catch (e) {
          message.error(e.message);
        }
      }
    });
  };

  return (
    <React.Fragment>
      <Button onClick={isVisible.setTrue}>Přidat</Button>

      <Modal
        title="Vytvoření nového uživatele"
        visible={isVisible.value}
        onOk={handleSubmit}
        okText="Uložit"
        cancelText="Zrušit"
        onCancel={isVisible.setFalse}
        confirmLoading={isLoading}
      >
        <Form>
          <Form.Item label="Uživatelské jméno">
            {form.getFieldDecorator('username')(<Input />)}
          </Form.Item>
          <Form.Item label="E-mail">
            {form.getFieldDecorator('email')(<Input />)}
          </Form.Item>
          <Form.Item label="Expirace">
            {form.getFieldDecorator('expirationDateTime')(<DatePicker />)}
          </Form.Item>
          <Form.Item label="Role">
            {form.getFieldDecorator('role', {
              initialValue: Groups.registered,
            })(
              <Radio.Group>
                <Radio.Button value={Groups.admin}>admin</Radio.Button>
                <Radio.Button value={Groups.office}>redakce</Radio.Button>
                <Radio.Button value={Groups.external}>externista</Radio.Button>
                <Radio.Button value={Groups.registered}>
                  registrovaný
                </Radio.Button>
              </Radio.Group>,
            )}
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default Form.create()(CreateUserForm);
