import { Button, Form, Input, message, Modal, Radio } from 'antd';
import DatePicker from 'antd/lib/date-picker';
import { FormComponentProps } from 'antd/lib/form';
import * as moment from 'moment';
import * as React from 'react';
import { MutationFn, OperationVariables } from 'react-apollo';
import { Groups } from '../../../../../shared/types/permissions';
import { useBoolean } from '../../../../customHooks';

interface IProps extends FormComponentProps {
  user: any;
  editUser: MutationFn<any, OperationVariables>;
  isLoading: boolean;
}

const EditUserForm = ({
  user: { username, email, role, expirationDateTime },
  editUser,
  isLoading,
  form,
}: IProps) => {
  const isVisible = useBoolean(false);

  const handleSubmit = () => {
    form.validateFieldsAndScroll(async (err, values) => {
      if (!err) {
        try {
          console.warn(values);
          const updatedUser = await editUser({
            variables: { username, ...values },
          });

          if (updatedUser) {
            message.success('Uživatel úspěšně upraven.');
            form.resetFields();
            isVisible.setFalse();
          }
        } catch (e) {
          message.error(e.message);
          form.resetFields();
          isVisible.setFalse();
        }
      }
    });
  };

  return (
    <React.Fragment>
      <Button shape="circle" icon="edit" onClick={isVisible.setTrue} />

      <Modal
        title={`Upravit ${username}`}
        visible={isVisible.value}
        onOk={handleSubmit}
        okText="Uložit"
        cancelText="Zrušit"
        onCancel={isVisible.setFalse}
        confirmLoading={isLoading}
      >
        <Form>
          <Form.Item label="Uživatelské jméno">
            <Input defaultValue={username} disabled={true} />
          </Form.Item>
          <Form.Item label="E-mail">
            <Input defaultValue={email} disabled={true} />
          </Form.Item>
          <Form.Item label="Expirace">
            {form.getFieldDecorator('expirationDateTime', {
              initialValue: expirationDateTime
                ? moment(expirationDateTime)
                : undefined,
            })(<DatePicker />)}
          </Form.Item>
          <Form.Item label="Role">
            {form.getFieldDecorator('role', {
              initialValue: role,
            })(
              <Radio.Group>
                <Radio.Button value={Groups.admin}>admin</Radio.Button>
                <Radio.Button value={Groups.office}>redakce</Radio.Button>
                <Radio.Button value={Groups.external}>externista</Radio.Button>
                <Radio.Button value={Groups.registered}>
                  registrovaný
                </Radio.Button>
              </Radio.Group>,
            )}
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

const EditUserWrapper = Form.create()(EditUserForm);

export default EditUserWrapper;
