import * as moment from 'moment';
import * as React from 'react';
import { Query } from 'react-apollo';
import Table from '../../../components/Table';
import UserRole from '../../../components/UserRole';
import CreateUser from '../create/CreateUser';
import DeleteUser from '../delete/DeleteUser';
import EditUser from '../edit/EditUser';
import { USERS } from '../queries';

const columns = [
  {
    title: 'Uživatelské jméno',
    dataIndex: 'username',
  },
  {
    title: 'Expirace',
    dataIndex: 'expirationDateTime',
    render: (text: string) => (text ? moment(text).format('DD.MM.YYYY') : null),
  },
  {
    title: 'E-mail',
    dataIndex: 'email',
  },
  {
    title: 'Role',
    dataIndex: 'role',
    render: (text: string) => <UserRole value={text} />,
  },
  {
    title: 'Akce',
    dataIndex: 'id',
    render: (text: string, record: any) => (
      <React.Fragment>
        <EditUser user={record} />
        <DeleteUser user={record} />
      </React.Fragment>
    ),
  },
];

const UserList = () => (
  <Query query={USERS}>
    {({ loading, error, data }) => {
      if (error) {
        return null;
      }

      return (
        <React.Fragment>
          <CreateUser />
          <Table
            rowKey="id"
            loading={loading}
            dataSource={data.users}
            columns={columns}
          />
        </React.Fragment>
      );
    }}
  </Query>
);

export default UserList;
