import Auth from '@aws-amplify/auth';
import BackTop from 'antd/lib/back-top';
import LocaleProvider from 'antd/lib/locale-provider';
import cs_CZ from 'antd/lib/locale-provider/cs_CZ';
import * as React from 'react';
import * as ReactGA from 'react-ga';
import { connect } from 'react-redux';
import { withRouter } from 'react-router-dom';
import {
  AWS_CLIENTAPP,
  AWS_IDENTITYPOOL,
  AWS_REGION,
} from '../../../shared/config';
import Helmet from '../components/Helmet';
import Router from '../router/components/Router';
import { AppMountedAction, appMountedAction } from './actions';

interface IProps {
  appMounted: AppMountedAction;
}

Auth.configure({
  region: AWS_REGION,
  userPoolId: AWS_IDENTITYPOOL,
  userPoolWebClientId: AWS_CLIENTAPP,
  mandatorySignIn: true,
});

class App extends React.Component<IProps> {
  public componentDidMount() {
    this.props.appMounted();
    ReactGA.set({ page: location.pathname });
    ReactGA.pageview(location.pathname);
  }

  public render() {
    return (
      <LocaleProvider locale={cs_CZ}>
        <React.Fragment>
          <Helmet />
          <BackTop />
          <Router />
        </React.Fragment>
      </LocaleProvider>
    );
  }
}

export default withRouter(connect(
  () => ({}),
  {
    appMounted: appMountedAction,
  },
)(App) as any);
