import * as React from 'react';
import { Query } from 'react-apollo';
import { RouteComponentProps } from 'react-router-dom';
import ErrorMessage from '../../components/ErrorMessage';
import Helmet from '../../components/Helmet';
import Loader from '../../components/Loader';
import Page from '../../components/Page';
import { ARTICLE } from '../queries';
import Detail from './Detail';

interface IProps extends RouteComponentProps<{ articleSlug: string }> {}

const ArticleDetail = ({ match }: IProps) => {
  const { articleSlug } = match.params;
  return (
    <Page>
      <Query query={ARTICLE} variables={{ slug: articleSlug }}>
        {({ loading, error, data }) => {
          if (loading) {
            return <Loader />;
          }

          if (error) {
            return <ErrorMessage message={error.message} />;
          }

          return (
            <React.Fragment>
              <Helmet title={data.article.title} />
              <Detail {...data.article} />
            </React.Fragment>
          );
        }}
      </Query>
    </Page>
  );
};

export default ArticleDetail;
