import Icon from 'antd/lib/icon';
import Spin from 'antd/lib/spin';
import Typography from 'antd/lib/typography';
import * as React from 'react';
import YouTube from 'react-youtube';
import styled from 'styled-components';
import { IArticle } from '../../../../shared/types/article';
import { useBoolean } from '../../../customHooks';
import AverageScore from '../../components/AverageScore';
import FBShareButton from '../../components/FBShareButton';
import Link from '../../components/Link';
import Score from '../../score/Score';
import { ARTICLE } from '../queries';
const { Text } = Typography;

const Image = styled.div`
  ${(props: { path: string }) => `
      background-image: url(${props.path});
      background-size: cover;
      background-position: center;
      width: 100%;
      height: 300px;
      margin-bottom: 10px;
  `};
`;

const Wrapper = styled.div`
  margin-bottom: 1em;
`;

const LinkWrapper = styled.div`
  margin-top: 50px;
  text-align: center;
`;
const Header = styled.div`
  margin-bottom: 1em;

  h1 {
    margin-bottom: 0;
    display: inline-flex;
    margin-right: 0.5em;
  }
`;

const Username = styled.div`
  width: 100%;
  text-align: right;
`;

const Actions = styled.div`
  display: grid;
  grid-template-columns: auto 120px 30px;
  grid-template-rows: 25px;
  grid-column-gap: 5px;
  align-items: center;
  justify-items: right;

  & > span {
    justify-self: left;
  }
`;

const Detail = (props: IArticle) => {
  const { title, text, slug, image, video, averageScore } = props;
  const isVideoLoading = useBoolean(!!video);
  return (
    <Wrapper>
      {!video && image && <Image path={image} />}
      {video && (
        <Spin
          spinning={isVideoLoading.value}
          indicator={
            <Icon type="loading" style={{ fontSize: 30 }} spin={true} />
          }
        >
          <YouTube
            videoId={video}
            opts={{
              height: '300',
              width: '100%',
            }}
            onReady={isVideoLoading.setFalse}
          />
        </Spin>
      )}
      <Header>
        <h1>{title}</h1>
        <Actions>
          <AverageScore value={averageScore} />
          <Score
            refetchQueries={[{ query: ARTICLE, variables: { slug } }]}
            itemId={props._id}
          />
          <FBShareButton />
        </Actions>
      </Header>
      {text && (
        <div
          dangerouslySetInnerHTML={{ __html: text.replace(/\n/g, '<br />') }}
        />
      )}
      <LinkWrapper>
        <Link to={`${slug}/diskuze`}>
          Vstoupit do diskuze{' '}
          <Icon type="right" style={{ marginLeft: '10px' }} />
        </Link>
      </LinkWrapper>
      <Username>
        {props.user && (
          <Text type="secondary">Autor: {props.user.username}</Text>
        )}
      </Username>
    </Wrapper>
  );
};
export default Detail;
