import * as React from 'react';
import { IArticle } from '../../../../shared/types/article';
import { ICategory } from '../../../../shared/types/category';
import Empty from '../../components/Empty';
import Helmet from '../../components/Helmet';
import LoadMoreContainer from '../../components/LoadMoreContainer';
import { ARTICLES } from '../queries';
import ListItem from './ListItem';

interface IListProps {
  dataSource: {
    articles: IArticle[];
  };
}

interface IProps {
  category: ICategory;
}

const List = ({ dataSource }: IListProps) => (
  <div>
    {!dataSource.articles.length && <Empty />}
    {dataSource.articles.map((article: IArticle) => (
      <ListItem key={article._id} {...article} />
    ))}
  </div>
);

const ArticleList = ({ category }: IProps) => (
  <React.Fragment>
    <Helmet title={category.title} />
    <LoadMoreContainer
      size={category.articleCount}
      listComponent={List}
      query={ARTICLES}
      queryVariables={{
        categoryId: category._id,
      }}
    />
  </React.Fragment>
);

export default ArticleList;
