import Icon from 'antd/lib/icon';
import { Push } from 'connected-react-router';
import * as moment from 'moment';
import * as React from 'react';
import * as striptags from 'striptags';
import styled from 'styled-components';
import { IArticle } from '../../../../shared/types/article';
import { useBoolean } from '../../../customHooks';
import withRouter from '../../hoc/withRouter';
import { getArticlePath } from '../utils';

const Date = styled.div`
  font-size: 11px;
  color: #aaa;
`;

const Text = styled.div`
  display: -webkit-box;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
}
`;

const Image = styled.div`
  ${(props: { path: string }) => `
      background-image: url(${props.path});
      background-size: cover;
      background-position: center;
      width: 15%;
      border-radius: 3px;
      margin: 0 20px 0px 0;
      
  `};
`;
const Wrapper = styled.div`
  position: relative;
  cursor: pointer;
  height: 150px;
  overflow: hidden;
`;

const Content = styled.div`
  display: flex;
  margin: auto;
  padding: 10px;
  height: 100%;
  width: 100%;
  border-bottom: 1px solid #e4e4e4;
`;

const Overlay = styled.div`
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(255, 255, 255, 0.8);
  display: flex;
  justify-content: center;
  align-items: center;
  font-size: 18px;
  flex-direction: column;
`;

interface IProps extends IArticle {
  push: Push;
}

export const ListItem = ({ push, ...article }: IProps) => {
  const { title, image, text, createdDateTime } = article;
  const hovered = useBoolean(false);

  const handleClick = () => push(getArticlePath(article));

  return (
    <Wrapper
      onMouseEnter={hovered.setTrue}
      onMouseLeave={hovered.setFalse}
      onClick={handleClick}
    >
      {hovered.value ? (
        <Overlay>
          <div>
            <Icon type="plus" />
          </div>
          <div>Přečíst článek</div>
        </Overlay>
      ) : null}
      <Content>
        {image && <Image path={image} />}
        <div style={{ width: '100%' }}>
          <h3>{title}</h3>
          <Date>{moment(createdDateTime).format('DD.MM.YYYY')}</Date>
          <Text>{text ? striptags(text) : null}</Text>
        </div>
      </Content>
    </Wrapper>
  );
};
export default withRouter(ListItem);
