import {
  AUTH_LOGOUT_USER,
  AUTH_SET_AUTH_DATA,
  AUTH_SET_AUTH_STATE,
  AUTH_SET_IS_LOADING,
  AUTH_SET_NEW_PASSWORD,
  AUTH_SIGN_IN,
  AUTH_STATE,
} from './constants';
import { IAuthData } from './reducer';

// Set auth state
export type AuthSetAuthStateAction = (
  authState: AUTH_STATE,
) => IAuthSetAuthStateActionResponse;

export interface IAuthSetAuthStateActionResponse {
  type: AUTH_SET_AUTH_STATE;
  authState: AUTH_STATE;
}

export const authSetAuthStateAction: AuthSetAuthStateAction = (
  authState: AUTH_STATE,
) => ({
  type: AUTH_SET_AUTH_STATE,
  authState,
});

// Set auth data
export type AuthSetAuthDataAction = (
  authData: IAuthData,
) => IAuthSetAuthDataActionResponse;

export interface IAuthSetAuthDataActionResponse {
  type: AUTH_SET_AUTH_DATA;
  authData: IAuthData;
}

export const authSetAuthDataAction: AuthSetAuthDataAction = (
  authData: IAuthData,
) => ({
  type: AUTH_SET_AUTH_DATA,
  authData,
});

// Sign in
export type AuthSignInAction = (
  username: string,
  password: string,
) => IAuthSignInActionResponse;

export interface IAuthSignInActionResponse {
  type: AUTH_SIGN_IN;
  username: string;
  password: string;
}

export const authSignInAction: AuthSignInAction = (
  username: string,
  password: string,
) => ({
  type: AUTH_SIGN_IN,
  username,
  password,
});

// Set new password
export type AuthSetNewPasswordAction = (
  password: string,
) => IAuthSetNewPasswordActionResponse;

export interface IAuthSetNewPasswordActionResponse {
  type: AUTH_SET_NEW_PASSWORD;
  password: string;
}

export const authSetNewPasswordAction: AuthSetNewPasswordAction = (
  password: string,
) => ({
  type: AUTH_SET_NEW_PASSWORD,
  password,
});

// Auth logout
export type AuthLogoutAction = () => IAuthLogoutActionResponse;

export interface IAuthLogoutActionResponse {
  type: AUTH_LOGOUT_USER;
}

export const authLogoutAction: AuthLogoutAction = () => ({
  type: AUTH_LOGOUT_USER,
});

// Set is loading
export type AuthSetIsLoadingAction = (
  isLoading: boolean,
) => IAuthSetIsLoadingActionResponse;

export interface IAuthSetIsLoadingActionResponse {
  type: AUTH_SET_IS_LOADING;
  isLoading: boolean;
}

export const authSetIsLoadingAction: AuthSetIsLoadingAction = (
  isLoading: boolean,
) => ({
  type: AUTH_SET_IS_LOADING,
  isLoading,
});

export type Action =
  | IAuthSetAuthStateActionResponse
  | IAuthSetAuthDataActionResponse
  | IAuthSignInActionResponse
  | IAuthSetNewPasswordActionResponse
  | IAuthLogoutActionResponse
  | IAuthSetIsLoadingActionResponse;
