import Button from 'antd/lib/button';
import Form from 'antd/lib/form';
import { FormComponentProps } from 'antd/lib/form/Form';
import Icon from 'antd/lib/icon';
import Input from 'antd/lib/input';
import message from 'antd/lib/message';
import * as React from 'react';
import { connect } from 'react-redux';
import { useBoolean } from '../../../customHooks';
import { authSetAuthDataAction, authSetAuthStateAction } from '../actions';
import { forgotPassword } from '../api';
import { AUTH_STATE_FORGOT_PASSWORD_SUBMIT } from '../constants';

interface IProps extends FormComponentProps {
  setAuthState: any;
  setAuthData: any;
}

const ForgotPassword = ({ form, setAuthState, setAuthData }: IProps) => {
  const isLoading = useBoolean(false);

  const handleSubmit = (e: any) => {
    e.preventDefault();
    form.validateFields(async (err: any, values: any) => {
      if (!err) {
        try {
          isLoading.setTrue();
          const data: any = await forgotPassword(values.username);
          await setAuthData({ username: values.username });
          isLoading.setFalse();
          message.info(
            `Bezpečnostní kód pro změnu hesla Vám byl odeslán na email ${
              data.CodeDeliveryDetails.Destination
            }`,
          );
          await setAuthState(AUTH_STATE_FORGOT_PASSWORD_SUBMIT);
        } catch (e) {
          isLoading.setFalse();
          message.error(e.message);
        }
      }
    });
  };

  const { getFieldDecorator } = form;
  return (
    <Form onSubmit={handleSubmit}>
      <Form.Item>
        {getFieldDecorator('username', {
          rules: [
            { required: true, message: 'Prosím zadejte uživatelské jméno!' },
          ],
        })(
          <Input
            prefix={<Icon type="user" style={{ color: 'rgba(0,0,0,.25)' }} />}
            placeholder="Uživatelské jméno"
          />,
        )}
      </Form.Item>
      <Form.Item>
        <Button type="primary" htmlType="submit" loading={isLoading.value}>
          Potvrdit
        </Button>
      </Form.Item>
    </Form>
  );
};

export default connect(
  () => ({}),
  {
    setAuthState: authSetAuthStateAction,
    setAuthData: authSetAuthDataAction,
  },
)(Form.create()(ForgotPassword));
