import Button from 'antd/lib/button';
import Form from 'antd/lib/form';
import { FormComponentProps } from 'antd/lib/form/Form';
import Input from 'antd/lib/input';
import message from 'antd/lib/message';
import * as React from 'react';
import { connect } from 'react-redux';
import { useBoolean } from '../../../customHooks';
import { IState } from '../../../types';
import { authSetAuthDataAction, authSetAuthStateAction } from '../actions';
import { forgotPasswordSubmit } from '../api';
import { selectUsername } from '../reducer';

interface IProps extends FormComponentProps {
  setAuthState: any;
  setAuthData: any;
  username: string;
  handleClose: () => void;
}

const ForgotPasswordSubmit = ({
  form,
  setAuthState,
  setAuthData,
  username,
  handleClose,
}: IProps) => {
  const isLoading = useBoolean(false);
  const handleSubmit = (e: any) => {
    e.preventDefault();
    form.validateFields(async (err: any, values: any) => {
      if (!err) {
        try {
          isLoading.setTrue();
          await forgotPasswordSubmit(username, values.code, values.password);
          message.success('Heslo bylo úspěšně změněno');
          form.resetFields();
          isLoading.setFalse();
          handleClose();
        } catch (e) {
          message.error(e.message);
        }
      }
    });
  };

  const { getFieldDecorator } = form;
  return (
    <Form onSubmit={handleSubmit}>
      <Form.Item>
        {getFieldDecorator('code', {
          rules: [
            {
              required: true,
              message:
                'Prosím zadejte bezpečnostní kód který jste obdrželi na email!',
            },
          ],
        })(<Input placeholder="Bezpečnostní kód" />)}
      </Form.Item>
      <Form.Item>
        {getFieldDecorator('password', {
          rules: [{ required: true, message: 'Prosím zadejte nové heslo!' }],
        })(<Input.Password placeholder="Heslo" />)}
      </Form.Item>
      <Form.Item>
        <Button type="primary" htmlType="submit" loading={isLoading.value}>
          Potvrdit
        </Button>
      </Form.Item>
    </Form>
  );
};

export default connect(
  (state: IState) => ({
    username: selectUsername(state),
  }),
  {
    setAuthState: authSetAuthStateAction,
    setAuthData: authSetAuthDataAction,
  },
)(Form.create()(ForgotPasswordSubmit));
