import Button from 'antd/lib/button';
import Form from 'antd/lib/form';
import { FormComponentProps } from 'antd/lib/form/Form';
import Icon from 'antd/lib/icon';
import Input from 'antd/lib/input';
import message from 'antd/lib/message';
import * as React from 'react';
import { connect } from 'react-redux';
import styled from 'styled-components';
import { useBoolean } from '../../../customHooks';
import Link from '../../components/Link';
import { authSetAuthDataAction, authSetAuthStateAction } from '../actions';
import { currentAuthenticatedUser, signIn } from '../api';
import {
  AUTH_STATE_AUTHENTICATED,
  AUTH_STATE_FORGOT_PASSWORD,
  AUTH_STATE_SET_NEW_PASSWORD,
} from '../constants';

interface IProps extends FormComponentProps {
  setAuthState: any;
  setAuthData: any;
}

const Actions = styled.div`
  display: flex;
  justify-content: space-between;
`;

const Login = ({ form, setAuthState, setAuthData }: IProps) => {
  const isLoading = useBoolean(false);

  const handleSubmit = (e: any) => {
    e.preventDefault();
    form.validateFields(async (err: any, values: any) => {
      if (!err) {
        try {
          isLoading.setTrue();
          const data = await signIn(values.username, values.password);
          await setAuthData(data);

          if ('challengeName' in data) {
            const { challengeName } = data;
            if (challengeName === 'NEW_PASSWORD_REQUIRED') {
              await setAuthState(AUTH_STATE_SET_NEW_PASSWORD);
            }
          } else {
            const authData = await currentAuthenticatedUser();
            await setAuthData(authData);
            await setAuthState(AUTH_STATE_AUTHENTICATED);
            message.success('Úspěšné přihlášení');
          }
        } catch (e) {
          if (
            e.code === 'NotAuthorizedException' ||
            e.code === 'UserNotFoundException'
          ) {
            message.info('Chybné uživatelské jméno nebo heslo');
          } else {
            message.error(e.message);
          }
          isLoading.setFalse();
        }
      }
    });
  };

  const handleSetAuthStateForgot = () => {
    setAuthState(AUTH_STATE_FORGOT_PASSWORD);
  };

  const { getFieldDecorator } = form;
  return (
    <Form onSubmit={handleSubmit}>
      <Form.Item>
        {getFieldDecorator('username', {
          rules: [
            { required: true, message: 'Prosím zadejte uživatelské jméno!' },
          ],
        })(
          <Input
            prefix={<Icon type="user" style={{ color: 'rgba(0,0,0,.25)' }} />}
            placeholder="Uživatelské jméno"
          />,
        )}
      </Form.Item>
      <Form.Item>
        {getFieldDecorator('password', {
          rules: [{ required: true, message: 'Prosím zadejte heslo!' }],
        })(
          <Input.Password
            prefix={<Icon type="lock" style={{ color: 'rgba(0,0,0,.25)' }} />}
            placeholder="Heslo"
          />,
        )}
      </Form.Item>
      <Form.Item>
        <Actions>
          <Link onClick={handleSetAuthStateForgot}>Zapomenuté heslo</Link>
          <Button type="primary" htmlType="submit" loading={isLoading.value}>
            Přihlásit
          </Button>
        </Actions>
      </Form.Item>
    </Form>
  );
};

export default connect(
  () => ({}),
  {
    setAuthState: authSetAuthStateAction,
    setAuthData: authSetAuthDataAction,
  },
)(Form.create()(Login));
