import Alert from 'antd/lib/alert';
import Form, { FormComponentProps } from 'antd/lib/form';
import Input from 'antd/lib/input';
import message from 'antd/lib/message';
import Modal from 'antd/lib/modal';
import * as React from 'react';
import { MutationFn, OperationVariables } from 'react-apollo';
import { Groups } from '../../../../shared/types/permissions';
import { useBoolean } from '../../../customHooks';
import Link from '../../components/Link';
import RULES from '../../form/rules';

interface IProps extends FormComponentProps {
  signup: MutationFn<
    { username: string; email: string; role: string },
    OperationVariables
  >;
  isLoading: boolean;
}

const SignupForm = ({ signup, isLoading, form }: IProps) => {
  const isVisible = useBoolean(false);

  const handleSubmit = () => {
    form.validateFieldsAndScroll(async (err, values) => {
      if (!err) {
        try {
          const variables = { ...values, role: Groups.registered };
          const createdUser = await signup({ variables });

          if (createdUser) {
            message.success(
              'Registrace proběhla úspěšně. Informace pro přihlášení vám byly odeslány na email.',
            );
            form.resetFields();
            isVisible.setFalse();
          }
        } catch (e) {
          message.error(e.message);
        }
      }
    });
  };

  return (
    <React.Fragment>
      <Link onClick={isVisible.setTrue}>Registrovat</Link>

      <Modal
        title="Registrace"
        visible={isVisible.value}
        onOk={handleSubmit}
        cancelText="Zrušit"
        okText="Potvrdit"
        onCancel={isVisible.setFalse}
        confirmLoading={isLoading}
      >
        <Alert
          message="Pro registraci si zvolte uživatelské jméno a vyplňte Váš email, na který Vám budou zaslány údaje pro první přihlášení."
          type="info"
          showIcon={true}
        />
        <Form>
          <Form.Item label="Uživatelské jméno">
            {form.getFieldDecorator('username', RULES.SIGNUP_USERNAME)(
              <Input />,
            )}
          </Form.Item>
          <Form.Item label="E-mail">
            {form.getFieldDecorator('email', RULES.SIGNUP_EMAIL)(<Input />)}
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default Form.create()(SignupForm);
