import * as moment from 'moment';
import { Groups } from '../../../shared/types/permissions';
import { IState } from '../../types';
import { Action } from './actions';
import {
  AUTH_SET_AUTH_DATA,
  AUTH_SET_AUTH_STATE,
  AUTH_SET_IS_LOADING,
  AUTH_STATE,
  AUTH_STATE_DEFAULT,
} from './constants';
const get = require('lodash/get');

export interface IAuthData {
  authenticationFlowType?: string;
  challengeName?: string;
  client?: {
    endpoint: string;
    userAgent: string;
  };
  signInUserSession?: {
    accessToken: {
      jwtToken: string;
    };
    idToken: {
      payload: any;
    };
  };
  username?: string;
  attributes?: {
    sub: string;
  };
}

export interface IAuthReducer {
  authData: IAuthData;
  authState: AUTH_STATE;
  totp?: string;
  isLoading: boolean;
}

const initialState: IAuthReducer = {
  authData: {},
  authState: AUTH_STATE_DEFAULT,
  totp: undefined,
  isLoading: true,
};

export default (state = initialState, action: Action) => {
  switch (action.type) {
    case AUTH_SET_AUTH_STATE: {
      const { authState } = action;
      return { ...state, authState };
    }
    case AUTH_SET_AUTH_DATA: {
      const { authData } = action;
      return { ...state, authData };
    }
    case AUTH_SET_IS_LOADING: {
      const { isLoading } = action;
      return { ...state, isLoading };
    }
    default:
      return state;
  }
};

export const selectToken = (state: IState) =>
  get(state, 'authReducer.authData.signInUserSession.accessToken.jwtToken');

export const selectExpirationDate = (state: IState) =>
  get(state, 'authReducer.authData.attributes.custom:expirationDate');

export const selectUsername = (state: IState) =>
  state.authReducer.authData.username;

export const selectAuthData = (state: IState) => state.authReducer.authData;

export const selectAuthState = (state: IState) => state.authReducer.authState;

export const selectIsLoading = (state: IState) => state.authReducer.isLoading;

export const selectGroups = (state: IState) =>
  get(
    state.authReducer.authData,
    'signInUserSession.idToken.payload.cognito:groups',
    [],
  );

export const selectHasPermission = (state: IState) => (
  groups: string[],
): boolean => {
  const hasGroup =
    groups.filter(n => selectGroups(state).includes(n)).length > 0;

  if (selectGroups(state).includes(Groups.registered)) {
    const isExpired = moment().isSameOrAfter(selectExpirationDate(state));
    return !isExpired && hasGroup;
  }
  return hasGroup;
};
