import message from 'antd/lib/message';
import { SagaIterator } from 'redux-saga';
import { call, put, select, takeLatest } from 'redux-saga/effects';
import { APP_MOUNTED } from '../app/constants';
import {
  authSetAuthDataAction,
  authSetAuthStateAction,
  authSetIsLoadingAction,
  IAuthSetNewPasswordActionResponse,
} from './actions';
import { currentAuthenticatedUser, setNewPassword, signOut } from './api';
import {
  AUTH_LOGOUT_USER,
  AUTH_SET_NEW_PASSWORD,
  AUTH_STATE_AUTHENTICATED,
  AUTH_STATE_SIGNED_OUT,
} from './constants';
import { selectAuthData } from './reducer';

function* setNewPasswordSaga({
  password,
}: IAuthSetNewPasswordActionResponse): SagaIterator {
  try {
    yield put(authSetIsLoadingAction(true));
    const authData = yield select(selectAuthData);
    const data = yield call(setNewPassword, authData, password);

    yield put(authSetAuthDataAction(data));
    yield put(authSetAuthStateAction(AUTH_STATE_AUTHENTICATED));
    message.success('Úspěšné přihlášení');
  } catch (e) {
    message.error(e.message);
  } finally {
    yield put(authSetIsLoadingAction(false));
  }
}

function* loginCurrentUserSaga(): SagaIterator {
  try {
    yield put(authSetIsLoadingAction(true));
    const data = yield call(currentAuthenticatedUser);
    yield put(authSetAuthStateAction(AUTH_STATE_AUTHENTICATED));
    yield put(authSetAuthDataAction(data));
  } catch (e) {
    console.log(e);
  } finally {
    yield put(authSetIsLoadingAction(false));
  }
}

function* logoutUserSaga(): SagaIterator {
  try {
    yield call(signOut);
    yield put(authSetAuthStateAction(AUTH_STATE_SIGNED_OUT));
    yield put(authSetAuthDataAction({}));
  } catch (e) {
    message.error(e.message);
  }
}

function* saga(): SagaIterator {
  yield takeLatest(AUTH_SET_NEW_PASSWORD, setNewPasswordSaga);
  yield takeLatest(AUTH_LOGOUT_USER, logoutUserSaga);
  yield takeLatest(APP_MOUNTED, loginCurrentUserSaga);
}

export default saga;
