import * as React from 'react';
import { Mutation } from 'react-apollo';
import { connect } from 'react-redux';
import { IArticle } from '../../../../shared/types/article';
import { createCommentPermissions } from '../../../../shared/types/permissions';
import { IState } from '../../../types';
import { selectHasPermission } from '../../auth/reducer';
import { CREATE_COMMENT } from '../mutations';
import { ARTICLE } from '../queries';
import CreateCommentForm from './CreateCommentForm';

interface IProps {
  article: IArticle;
  hasPermission: (groups: string[]) => boolean;
}

const CreateComment = ({ article, hasPermission }: IProps) => {
  if (!hasPermission(createCommentPermissions)) {
    return null;
  }

  return (
    <Mutation
      mutation={CREATE_COMMENT}
      refetchQueries={[{ query: ARTICLE, variables: { slug: article.slug } }]}
    >
      {(createComment, { loading }) => (
        <CreateCommentForm
          createComment={createComment}
          loading={loading}
          article={article}
        />
      )}
    </Mutation>
  );
};

export default connect(
  (state: IState) => ({
    hasPermission: selectHasPermission(state),
  }),
  {},
)(CreateComment);
