import Form from 'antd/lib/form';
import { FormComponentProps } from 'antd/lib/form/Form';
import Icon from 'antd/lib/icon';
import Input from 'antd/lib/input';
import message from 'antd/lib/message';
import Modal from 'antd/lib/modal';
import * as React from 'react';
import styled from 'styled-components';
import { IArticle } from '../../../../shared/types/article';
import { useBoolean } from '../../../customHooks';
import Button from '../../components/Button';

interface IProps extends FormComponentProps {
  createComment: any;
  loading: boolean;
  article: IArticle;
}

const Link = styled.div`
  display: flex;
  justify-content: center;
  padding: 10px;
`;

const CreateCommentForm = ({
  form,
  createComment,
  loading,
  article,
}: IProps) => {
  const isVisible = useBoolean(false);

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    form.validateFieldsAndScroll(async (err: any, values: any) => {
      if (!err) {
        try {
          const variables = {
            data: {
              ...values,
              articleId: article._id,
            },
          };

          const createdComment = await createComment({ variables });

          if (createdComment) {
            message.success('Komentář úspěšně přidán');
            form.resetFields();
            isVisible.setFalse();
          }
        } catch (e) {
          message.error(e.message);
          form.resetFields();
          isVisible.setFalse();
        }
      }
    });
  };

  return (
    <React.Fragment>
      <Link>
        <Button onClick={isVisible.setTrue}>
          <Icon type="plus" style={{ marginRight: '5px' }} />
          Přidat komentář
        </Button>
      </Link>

      <Modal
        title="Nový komentář"
        visible={isVisible.value}
        onOk={handleSubmit}
        okText="Uložit"
        onCancel={isVisible.setFalse}
        cancelText="Zrušit"
        confirmLoading={loading}
      >
        <Form onSubmit={handleSubmit}>
          <Form.Item label="Text">
            {form.getFieldDecorator('text')(<Input.TextArea />)}
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  );
};

export default Form.create()(CreateCommentForm);
