import AntdComment from 'antd/lib/comment';
import Typography from 'antd/lib/typography';
import * as moment from 'moment';
import * as React from 'react';
import styled from 'styled-components';
import { IArticle } from '../../../../shared/types/article';
import { IComment } from '../../../../shared/types/comment';
import AverageScore from '../../components/AverageScore';
import Score from '../../score/Score';
import { ARTICLE } from '../queries';
const { Text } = Typography;

interface IProps {
  comment: IComment;
  article: IArticle;
}

const Content = styled.div`
  background: #fff;
  padding: 10px 25px;
  border-radius: 5px;
  margin: 5px 0;
`;

const Label = styled.span`
  padding: 0 5px;
  color: rgba(0, 0, 0, 0.75);
`;

const LabelDateTime = styled.span`
  padding: 0 5px;
  color: rgba(0, 0, 0, 0.75);
  float: right;
`;

const Actions = styled.div`
  display: flex;
  justify-content: space-between;
  margin-bottom: 10px;
`;

const Comment = ({ comment, article }: IProps) => (
  <React.Fragment>
    <AntdComment
      author={
        <Label>
          <Text type="secondary">
            {comment.user ? comment.user.username : null}
          </Text>
        </Label>
      }
      datetime={
        <LabelDateTime>
          <Text type="secondary">
            {moment(comment.createdDateTime).format('DD.MM.YYYY')}
          </Text>
        </LabelDateTime>
      }
      content={<Content>{comment.text}</Content>}
    />
    <Actions>
      <Label>
        <AverageScore value={comment.averageScore} />
      </Label>
      <Score
        refetchQueries={[{ query: ARTICLE, variables: { slug: article.slug } }]}
        itemId={comment._id}
      />
    </Actions>
  </React.Fragment>
);

export default Comment;
