import Icon from 'antd/lib/icon';
import * as React from 'react';
import { Query } from 'react-apollo';
import styled from 'styled-components';
import { IComment } from '../../../../shared/types/comment';
import { getArticlePath } from '../../article/utils';
import ErrorMessage from '../../components/ErrorMessage';
import Helmet from '../../components/Helmet';
import Link from '../../components/Link';
import Loader from '../../components/Loader';
import Page from '../../components/Page';
import CreateComment from '../create/CreateComment';
import { ARTICLE } from '../queries';
import Comment from './Comment';

interface IProps {
  match: {
    params: {
      articleSlug: string;
    };
  };
}

const Wrapper = styled.div`
  margin-top: 20px;

  .ant-comment-inner {
    padding: 0;
  }

  .ant-comment-avatar {
    display: none;
  }
`;

const CommentList = ({ match }: IProps) => {
  const { articleSlug } = match.params;
  return (
    <Page>
      <Query query={ARTICLE} variables={{ slug: articleSlug }}>
        {({ loading, error, data }) => {
          if (loading) {
            return <Loader />;
          }

          if (error) {
            return <ErrorMessage message={error.message} />;
          }

          return (
            <React.Fragment>
              <Helmet title={`Diskuze ke článku: ${data.article.title}`} />
              <Link to={getArticlePath(data.article)}>
                <Icon type="left" style={{ marginRight: '10px' }} />
                Zpět na článek
              </Link>
              <CreateComment article={data.article} />
              <Wrapper>
                {data.article.comments.map((comment: IComment) => (
                  <Comment
                    article={data.article}
                    key={comment._id}
                    comment={comment}
                  />
                ))}
              </Wrapper>
            </React.Fragment>
          );
        }}
      </Query>
    </Page>
  );
};

export default CommentList;
