import Divider from 'antd/lib/divider';
import { Push, push } from 'connected-react-router';
import * as React from 'react';
import { connect } from 'react-redux';
import { compose } from 'redux';
import styled from 'styled-components';
import { SHOW_ADS } from '../../../shared/config';
import { IState } from '../../types';
import Signup from '../auth/components/Signup';
import { AUTH_STATE, AUTH_STATE_AUTHENTICATED } from '../auth/constants';
import { selectAuthState, selectIsLoading } from '../auth/reducer';
import { Routes } from '../router/routes';
import Search from '../search/components/Search';
import LoginButton from './LoginButton';
import Spin from './Spin';
import UserMenu from './UserMenu';

const logo = require('../../logo.png');

export interface IProps {
  authState: AUTH_STATE;
  isLoading: boolean;
  push: Push;
}

const Root = styled.div`
  background-color: #fff;
`;

const Container = styled.div`
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 5px 15px;
  width: 80%;
  margin: auto;
  padding: 15px;

  @media only screen and (max-width: 1000px) {
    & {
      width: 100%;
    }
  }
`;

const Logo = styled.img`
  width: 110px;
  cursor: pointer;
`;

interface IColumn {
  flow?: string;
  justify: string;
  alignItems: string;
}

const Column = styled.div`
  width: 100%;
  display: flex;
  justify-content: ${(props: IColumn) => props.justify};
  align-items: ${(props: IColumn) => props.alignItems};
  height: 100%;
  flex-flow: ${(props: IColumn) => (props.flow ? props.flow : 'initial')};
`;

const Ad = styled.div`
  width: 80%;
  height: 100px;
  background: #aaa;
  margin: auto;
`;

const Header = ({ authState, isLoading, ...props }: IProps) => {
  const handleClick = () => props.push(Routes.home);
  return (
    <Root>
      {SHOW_ADS && <Ad>Reklama</Ad>}
      <Container>
        <Column justify="flex-start" alignItems="center">
          <Logo src={logo} onClick={handleClick} />
        </Column>
        <Column justify="center" alignItems="center">
          <Search />
        </Column>
        <Column justify="flex-end" flow="column" alignItems="flex-end">
          {authState === AUTH_STATE_AUTHENTICATED ? (
            <UserMenu />
          ) : isLoading ? (
            <Spin size={14} />
          ) : (
            <div>
              <LoginButton />
              <Divider type="vertical" />
              <Signup />
            </div>
          )}
        </Column>
      </Container>
    </Root>
  );
};

const mapStateToProps = (state: IState) => ({
  authState: selectAuthState(state),
  isLoading: selectIsLoading(state),
});

const mapDispatchToProps = {
  push,
};

export default compose(
  connect(
    mapStateToProps,
    mapDispatchToProps,
  ),
)(Header);
