import Icon from 'antd/lib/icon';
import { DocumentNode } from 'graphql';
import { max } from 'lodash';
import * as React from 'react';
import { Query } from 'react-apollo';
import styled from 'styled-components';
import { useBoolean } from '../../customHooks';
import Button from './Button';
import Loader from './Loader';

const ButtonWrapper = styled.div`
  padding: 20px;
  text-align: center;
`;

const limit = 5;

interface IProps {
  size: number;
  query: DocumentNode;
  queryVariables: any;
  listComponent: React.JSXElementConstructor<any>;
}

const LoadMoreContainer = ({
  query,
  queryVariables,
  listComponent: ListComponent,
  size,
}: IProps) => {
  // pagination
  const hasMore = useBoolean(size > limit);
  const moreLoading = useBoolean(false);
  const fetchMoreVariables = (start: number) => ({
    ...queryVariables,
    limit,
    start,
  });

  return (
    <Query query={query} variables={{ limit, ...queryVariables }}>
      {({ loading, error, data, fetchMore }) => {
        if (error) {
          console.log(error);
          return null; // TODO: show error
        }

        const loadMore = () => {
          const lengths = Object.values(data).map((a: []) => a.length);
          const offset = max(lengths || []) || 0;

          if (offset >= size) {
            hasMore.setFalse();
          }

          moreLoading.setTrue();

          fetchMore({
            query,
            updateQuery: (prev, { fetchMoreResult }) => {
              const moreResultLengths = Object.values(fetchMoreResult).map(
                (a: []) => a.length,
              );
              const moreResultOffset = max(moreResultLengths || []) || 0;

              if (moreResultOffset < limit) {
                hasMore.setFalse();
              }

              if (moreResultOffset === 0) {
                return prev;
              }

              const result = {};
              Object.keys(prev).forEach((key: string) => {
                result[key] = [...prev[key], ...fetchMoreResult[key]];
              });

              moreLoading.setFalse();
              return result;
            },
            variables: fetchMoreVariables(offset),
          });
        };

        return (
          <React.Fragment>
            {loading && <Loader />}
            {!loading && (
              <React.Fragment>
                <ListComponent dataSource={data} />
                {hasMore.value && (
                  <ButtonWrapper>
                    <Button onClick={loadMore}>
                      <Icon
                        type={moreLoading.value ? 'loading' : 'down'}
                        style={{ marginRight: '5px' }}
                      />
                      Zobrazit více
                    </Button>
                  </ButtonWrapper>
                )}
              </React.Fragment>
            )}
          </React.Fragment>
        );
      }}
    </Query>
  );
};

export default LoadMoreContainer;
