import { DocumentNode } from 'graphql';
import * as React from 'react';
import { Query } from 'react-apollo';
import { usePagination } from '../../customHooks';
import Table from './Table';

export const limit = 10;

interface IProps {
  rowKey: string;
  total: number;
  query: DocumentNode;
  queryVariables?: object;
  dataSourceKey: string;
  columns: any[];
}

export const LoadMoreTableContext = React.createContext({});

const LoadMoreTable = ({
  query,
  total,
  queryVariables,
  dataSourceKey,
  rowKey,
  columns,
}: IProps) => {
  const pagination = usePagination({ total, current: 1, pageSize: limit });
  const onChange = (p: any) => {
    pagination.setValue(p);
  };
  return (
    <LoadMoreTableContext.Provider value={{ pagination }}>
      <Query
        query={query}
        variables={{
          ...queryVariables,
          start: pagination.start,
          limit,
        }}
        fetchPolicy="cache-and-network"
      >
        {({ data, loading }) => (
          <Table
            rowKey={rowKey}
            columns={columns}
            pagination={pagination.value}
            dataSource={data[dataSourceKey] || []}
            loading={loading}
            onChange={onChange}
          />
        )}
      </Query>
    </LoadMoreTableContext.Provider>
  );
};

export default LoadMoreTable;
