import Modal from 'antd/lib/modal';
import * as React from 'react';
import { connect } from 'react-redux';
import { useBoolean } from '../../customHooks';
import { IState } from '../../types';
import { authSetAuthStateAction } from '../auth/actions';
import ForgotPassword from '../auth/components/ForgotPassword';
import ForgotPasswordSubmit from '../auth/components/ForgotPasswordSubmit';
import Login from '../auth/components/Login';
import SetNewPassword from '../auth/components/SetNewPassword';
import {
  AUTH_STATE,
  AUTH_STATE_DEFAULT,
  AUTH_STATE_FORGOT_PASSWORD,
  AUTH_STATE_FORGOT_PASSWORD_SUBMIT,
  AUTH_STATE_SET_NEW_PASSWORD,
} from '../auth/constants';
import { selectAuthState } from '../auth/reducer';
import Button from './Button';

interface IProps {
  authState: AUTH_STATE;
  setAuthState: any;
}

const getTitle = (authState: AUTH_STATE) => {
  switch (authState) {
    case AUTH_STATE_FORGOT_PASSWORD:
      return 'Zapomenuté heslo';
    case AUTH_STATE_FORGOT_PASSWORD_SUBMIT:
      return 'Zapomenuté heslo - potvrzení';
    case AUTH_STATE_SET_NEW_PASSWORD:
      return 'Nastavení nového hesla';
    default:
      return 'Přihlášení';
  }
};

const LoginButton = ({ authState, setAuthState }: IProps) => {
  const isVisible = useBoolean(false);

  const handleCancel = () => {
    isVisible.setFalse();
    setAuthState(AUTH_STATE_DEFAULT);
  };

  const getContent = () => {
    switch (authState) {
      case AUTH_STATE_FORGOT_PASSWORD:
        return <ForgotPassword />;
      case AUTH_STATE_FORGOT_PASSWORD_SUBMIT:
        return <ForgotPasswordSubmit handleClose={handleCancel} />;
      case AUTH_STATE_SET_NEW_PASSWORD:
        return <SetNewPassword />;
      default:
        return <Login />;
    }
  };

  return (
    <React.Fragment>
      <Button onClick={isVisible.setTrue}>Přihlásit se</Button>

      <Modal
        title={getTitle(authState)}
        visible={isVisible.value}
        onCancel={handleCancel}
        destroyOnClose={true}
        footer={null}
      >
        {getContent()}
      </Modal>
    </React.Fragment>
  );
};

export default connect(
  (state: IState) => ({
    authState: selectAuthState(state),
  }),
  {
    setAuthState: authSetAuthStateAction,
  },
)(LoginButton);
