import Divider from 'antd/lib/divider';
import Icon from 'antd/lib/icon';
import Typography from 'antd/lib/typography';
import { Push, push as pushAction } from 'connected-react-router';
import * as moment from 'moment';
import * as React from 'react';
import { connect } from 'react-redux';
import { compose } from 'redux';
import { adminAvailablePermission } from '../../../shared/types/permissions';
import { IState } from '../../types';
import { AuthLogoutAction, authLogoutAction } from '../auth/actions';
import {
  selectExpirationDate,
  selectHasPermission,
  selectUsername,
} from '../auth/reducer';
import { Routes } from '../router/routes';
import Button from './Button';
import Link from './Link';
const { Text } = Typography;

interface IProps {
  logout: AuthLogoutAction;
  username: string;
  push: Push;
  hasPermission: (groups: string[]) => boolean;
  expirationDate?: string;
}

const UserMenu = ({
  username,
  push,
  logout,
  hasPermission,
  expirationDate,
}: IProps) => (
  <React.Fragment>
    <div>
      {hasPermission(adminAvailablePermission) && (
        <React.Fragment>
          <Link to={Routes.admin}>admin</Link>
          <Divider type="vertical" />
        </React.Fragment>
      )}
      <Button onClick={logout}>
        Odhlásit <Icon type="logout" style={{ marginLeft: '5px' }} />
      </Button>
    </div>

    {expirationDate ? (
      <Text style={{ fontSize: '11px', padding: '0 7px' }} type="secondary">
        Expirace členství: {moment(expirationDate).format('DD.MM.YYYY')}
      </Text>
    ) : null}
  </React.Fragment>
);

const mapStateToProps = (state: IState) => ({
  username: selectUsername(state),
  expirationDate: selectExpirationDate(state),
  hasPermission: selectHasPermission(state),
});

const mapDispatchToProps = {
  logout: authLogoutAction,
  push: pushAction,
};

export default compose(
  connect(
    mapStateToProps,
    mapDispatchToProps,
  ),
)(UserMenu);
