import Divider from 'antd/lib/divider';
import * as React from 'react';
import { Query } from 'react-apollo';
import styled from 'styled-components';
import { useBoolean } from '../../../customHooks';
import Link from '../Link';
import Spin from '../Spin';
import { TOP_ARTICLE } from './queries';
import TopArticleContent from './TopArticleContent';

const Root = styled.div`
  width: 80%;
  margin: auto;
  padding: 0 15px;
  display: flex;
  justify-content: space-between;
  align-items: center;
  margin-top: 7px;

  @media only screen and (max-width: 1000px) {
    & {
      width: 100%;
    }
  }
`;

const Links = styled.div`
  margin: 0 0 0 1em;

  & > span {
    margin-right: 10px;
  }
`;

const TopArticle = () => {
  const isExpanded = useBoolean(false);

  return (
    <Query query={TOP_ARTICLE}>
      {({ loading, error, data }) => {
        if (error) {
          console.log(error);
          return null;
        }

        if (loading) {
          return <Spin size={15} />;
        }

        if (!data.articles.length) {
          return null;
        }

        return (
          <React.Fragment>
            <Root>
              <TopArticleContent
                title={data.articles[0].title}
                expanded={isExpanded.value}
              />
              <Links>
                <Link onClick={isExpanded.toggle}>
                  {isExpanded.value ? 'skrýt' : 'zobrazit'}
                </Link>
              </Links>
            </Root>
            <Divider style={{ margin: '10px 0 0 0' }} />
          </React.Fragment>
        );
      }}
    </Query>
  );
};

export default TopArticle;
