import Col from 'antd/lib/grid/col';
import Row from 'antd/lib/grid/row';
import * as React from 'react';
import { Query } from 'react-apollo';
import styled from 'styled-components';
import { IArticle } from '../../../../shared/types/article';
import ErrorMessage from '../../components/ErrorMessage';
import Loader from '../../components/Loader';
import LoadMoreContainer from '../../components/LoadMoreContainer';
import Page from '../../components/Page';
import { HOMEPAGE_ARTICLE_COUNT, HOMEPAGE_ARTICLES } from '../queries';
import ListItem from './ListItem';

interface IListProps {
  dataSource: any;
}

const Title = styled.div`
  margin: 0 0 0 15px;
  font-size: 16px;
  text-transform: uppercase;
  color: rgba(0, 0, 0, 0.35);
`;

export const List = ({ dataSource }: IListProps) => (
  <Row>
    <Col span={8}>
      <Title>Zákulisí</Title>
      {dataSource.zakulisi.map((article: IArticle) => (
        <ListItem key={article._id} {...article} />
      ))}
    </Col>
    <Col span={8}>
      <Title>Recenze</Title>
      {dataSource.recenze.map((article: IArticle) => (
        <ListItem key={article._id} {...article} />
      ))}
    </Col>
    <Col span={8}>
      <Title>Přehledy</Title>
      {dataSource.prehledy.map((article: IArticle) => (
        <ListItem key={article._id} {...article} />
      ))}
    </Col>
  </Row>
);

const Homepage = () => (
  <Page>
    <Query query={HOMEPAGE_ARTICLE_COUNT}>
      {({ loading, error, data }) => {
        if (error) {
          return <ErrorMessage message={error.message} />;
        }

        if (loading) {
          return <Loader />;
        }

        return (
          <LoadMoreContainer
            query={HOMEPAGE_ARTICLES}
            queryVariables={{}}
            size={data.homepageArticleCount}
            listComponent={List}
          />
        );
      }}
    </Query>
  </Page>
);

export default Homepage;
