import Menu, { ClickParam } from 'antd/lib/menu';
import * as React from 'react';
import { Query } from 'react-apollo';
import { compose } from 'redux';
import styled from 'styled-components';
import { ICategory } from '../../../../shared/types/category';
import Spin from '../../components/Spin';
import withRouter, { IWithRouterProps } from '../../hoc/withRouter';
import { NAVBAR_CATEGORIES } from '../queries';

const Root = styled.div`
  font-weight: 700;

  .ant-tabs-nav .ant-tabs-tab-active {
    font-weight: 700;
  }

  .ant-menu-root {
    padding: 0 10%;

    @media only screen and (max-width: 1000px) {
      padding: 0;
    }
  }
`;

const Navbar = ({ location, push }: IWithRouterProps) => {
  const handleClick = (param: ClickParam) => push(param.key);

  return (
    <Query query={NAVBAR_CATEGORIES}>
      {({ loading, error, data }) => {
        if (error) {
          console.log(error);
          return null;
        }

        if (loading) {
          return <Spin size={15} />;
        }

        return (
          <Root>
            <Menu
              onClick={handleClick}
              selectedKeys={[location.pathname]}
              mode="horizontal"
              style={{ backgroundColor: '#f5f5f5' }}
            >
              {data.categories.map((category: ICategory) => (
                <Menu.Item key={`/${category.slug}`}>
                  {category.title}
                </Menu.Item>
              ))}
            </Menu>
          </Root>
        );
      }}
    </Query>
  );
};

export default compose(withRouter)(Navbar);
