import * as React from 'react';
import { Query } from 'react-apollo';
import styled from 'styled-components';
import { SHOW_ADS } from '../../../../shared/config';
import ArticleList from '../../article/list/ArticleList';
import { CATEGORY } from '../../article/queries';
import ErrorMessage from '../../components/ErrorMessage';
import Loader from '../../components/Loader';
import Page from '../../components/Page';

interface IProps {
  match: {
    params: {
      categorySlug: string;
    };
  };
}

const Root = styled.div`
  display: flex;
`;
const Ad = styled.div`
  width: 300px;
  height: 600px;
  background: #aaa;
  margin: 0 12px;
`;
const List = styled.div`
  width: 100%;
`;

const Category = ({ match: { params } }: IProps) => (
  <Page>
    <Root>
      <List>
        <Query query={CATEGORY} variables={{ slug: params.categorySlug }}>
          {({ loading, error, data }) => {
            if (error) {
              return <ErrorMessage message={error.message} />;
            }

            if (loading) {
              return <Loader />;
            }

            return <ArticleList category={data.category} />;
          }}
        </Query>
      </List>
      {SHOW_ADS && <Ad>Reklama</Ad>}
    </Root>
  </Page>
);

export default Category;
