import * as React from 'react';
import { Query } from 'react-apollo';
import styled from 'styled-components';
import { SHOW_ADS } from '../../../../shared/config';
import { IArticle } from '../../../../shared/types/article';
import ListItem from '../../article/list/ListItem';
import ErrorMessage from '../../components/ErrorMessage';
import Helmet from '../../components/Helmet';
import Loader from '../../components/Loader';
import LoadMoreContainer from '../../components/LoadMoreContainer';
import Page from '../../components/Page';
import { SEARCH_ARTICLE_COUNT, SEARCH_ARTICLES } from '../../search/queries';

interface IProps {
  match: {
    params: {
      searchText: string;
    };
  };
}

const List = ({ dataSource }: any) => (
  <div>
    {dataSource.searchArticles.map((article: IArticle) => (
      <ListItem key={article._id} {...article} />
    ))}
  </div>
);

const Message = styled.div`
  text-align: center;
  font-size: 16px;
`;

const pluralizeArticle = (count: number) => {
  if (count === 1) {
    return 'článek';
  } else if (count > 1 && count <= 4) {
    return 'články';
  } else {
    return 'článků';
  }
};

const pluralizeFoundArticle = (count: number) => {
  if (count === 1) {
    return 'Nalezen';
  } else if (count > 1 && count <= 4) {
    return 'Nalezeny';
  } else {
    return 'Nalezeno';
  }
};

const Root = styled.div`
  display: flex;
`;

const Ad = styled.div`
  width: 300px;
  height: 600px;
  background: #aaa;
  margin: 0 12px;
`;

const ResultList = styled.div`
  width: 100%;
`;

const SearchResult = ({ match }: IProps) => (
  <Page>
    <Root>
      <ResultList>
        <Query
          query={SEARCH_ARTICLE_COUNT}
          variables={{ searchText: match.params.searchText }}
        >
          {({ loading, error, data }) => {
            if (error) {
              return <ErrorMessage message={error.message} />;
            }

            if (loading) {
              return <Loader />;
            }

            return (
              <React.Fragment>
                <Helmet title={`Vyhledávání: ${match.params.searchText}`} />
                <Message>
                  {pluralizeFoundArticle(data.searchArticleCount)}{' '}
                  <strong>{data.searchArticleCount}</strong>{' '}
                  {pluralizeArticle(data.searchArticleCount)} obsahující{' '}
                  <strong>"{match.params.searchText}"</strong>
                </Message>
                <LoadMoreContainer
                  size={data.searchArticleCount}
                  listComponent={List}
                  query={SEARCH_ARTICLES}
                  queryVariables={{
                    searchText: match.params.searchText,
                  }}
                />
              </React.Fragment>
            );
          }}
        </Query>
      </ResultList>
      {SHOW_ADS && <Ad>Reklama</Ad>}
    </Root>
  </Page>
);

export default SearchResult;
