import * as React from 'react';
import { connect } from 'react-redux';
import { Redirect, Route } from 'react-router-dom';
import { Groups } from '../../../../shared/types/permissions';
import { IState } from '../../../types';
import { selectHasPermission, selectIsLoading } from '../../auth/reducer';
import Loader from '../../components/Loader';
import { Routes } from '../routes';

interface IProps {
  path: string;
  exact?: boolean;
  component: any;
  permissions: Groups[];
  isLoading: boolean;
  hasPermission: (groups: string[]) => boolean;
}

const ProtectedRoute = ({
  component: Component,
  permissions,
  path,
  exact,
  hasPermission,
  isLoading,
}: IProps) => {
  if (isLoading) {
    return <Loader />;
  }

  const render = (props: any) => {
    if (!hasPermission(permissions)) {
      return <Redirect to={Routes.home} />;
    }

    return <Component {...props} />;
  };

  return <Route path={path} exact={exact} render={render} />;
};

export default connect(
  (state: IState) => ({
    hasPermission: selectHasPermission(state),
    isLoading: selectIsLoading(state),
  }),
  {},
)(ProtectedRoute);
