import * as React from 'react';
import { Route, Switch } from 'react-router-dom';
import { adminAvailablePermission } from '../../../../shared/types/permissions';
import Dashboard from '../../admin/Dashboard';
import ArticleDetail from '../../article/detail/ArticleDetail';
import CommentList from '../../comment/list/CommentList';
import Homepage from '../../homepage/components/Homepage';
import NotFound from '../../notFound';
import Category from '../../pages/components/Category';
import SearchResult from '../../pages/components/SearchResult';
import { Routes } from '../routes';
import ProtectedRoute from './ProtectedRoute';

const Router = () => (
  <Switch>
    <ProtectedRoute
      path={Routes.admin}
      component={Dashboard}
      permissions={adminAvailablePermission}
    />

    {/* Public */}
    <Route exact={true} path={Routes.home} component={Homepage} />
    <Route path="/vyhledat/:searchText" exact={true} component={SearchResult} />
    <Route path="/:categorySlug" exact={true} component={Category} />
    <Route
      path="/:categorySlug/:articleSlug"
      exact={true}
      component={ArticleDetail}
    />
    <Route path="/:categorySlug/:articleSlug/diskuze" component={CommentList} />
    <Route path="*" component={NotFound} />
  </Switch>
);

export default Router;
