import * as React from 'react';
import { Query } from 'react-apollo';
import { connect } from 'react-redux';
import { scorePermission } from '../../../shared/types/permissions';
import { IState } from '../../types';
import { selectHasPermission, selectIsLoading } from '../auth/reducer';
import Spin from '../components/Spin';
import CreateScore from './create/CreateScore';
import DeleteScore from './delete/DeleteScore';
import { SCORE } from './queries';

interface IProps {
  itemId: string;
  hasPermission: (groups: string[]) => boolean;
  isLoading: boolean;
  refetchQueries: any[];
}

const Score = (props: IProps) => {
  if (props.isLoading) {
    return <Spin size={15} />;
  }

  if (!props.hasPermission(scorePermission)) {
    return <div />;
  }

  const { itemId } = props;

  return (
    <Query query={SCORE} variables={{ itemId }}>
      {({ loading, error, data }) => {
        if (error) {
          console.log(error);
          return null;
        }

        if (loading) {
          return <Spin size={15} />;
        }

        const value = data.score && data.score.value;

        return (
          <div>
            <DeleteScore
              refetchQueries={props.refetchQueries}
              itemId={props.itemId}
              value={value}
            />
            <CreateScore {...props} value={value} />
          </div>
        );
      }}
    </Query>
  );
};

export default connect(
  (state: IState) => ({
    hasPermission: selectHasPermission(state),
    isLoading: selectIsLoading(state),
  }),
  {},
)(Score);
