import Icon from 'antd/lib/icon';
import message from 'antd/lib/message';
import Tooltip from 'antd/lib/tooltip';
import * as React from 'react';
import { Mutation } from 'react-apollo';
import styled from 'styled-components';
import { DELETE_SCORE } from '../mutations';
import { SCORE } from '../queries';

interface IProps {
  itemId: string;
  refetchQueries: any[];
  value?: number;
}

const IconWrapper = styled.span`
  cursor: pointer;
  // color: rgba(0, 0, 0, 0.45);

  &:hover {
    color: #1890ff;
  }
  padding: 0 10px;
`;

const DeleteScore = ({ itemId, refetchQueries, value }: IProps) => {
  if (value === null) {
    return null;
  }

  const handleClick = (deleteReaction: any) => () => {
    try {
      deleteReaction({ variables: { itemId } });
      message.success('Hodnocení úspěšně odebráno');
    } catch (e) {
      message.error(e.message);
    }
  };

  return (
    <Mutation
      mutation={DELETE_SCORE}
      refetchQueries={[
        ...refetchQueries,
        { query: SCORE, variables: { itemId } },
      ]}
    >
      {deleteReaction => (
        <Tooltip title="Odebrat hodnocení">
          <IconWrapper onClick={handleClick(deleteReaction)}>
            <Icon type="close-circle" />
          </IconWrapper>
        </Tooltip>
      )}
    </Mutation>
  );
};

export default DeleteScore;
